@@ -8,6 +8,8 @@
  * BaseBuild - Creation d'une base de programmation en langage C de type GNU avec les autotools
  * GNU General Public License
  *
+ *  This file is part of XCFA.
+ * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -250,7 +252,9 @@ gboolean FileIs_mpc (gchar *namefile)
 		lenread = fread (buf, 1, 1024, fp);
 		fclose (fp);
 	}
-	
+	// 
+	// MPCKSH
+	// 
 	for (cpt = 0; cpt < 1024; cpt ++) {
 		if (
 		    buf [ cpt + 0 ] == 0x4d &&	// M
@@ -261,6 +265,22 @@ gboolean FileIs_mpc (gchar *namefile)
 		    break;
 		}
 	}
+	if (FALSE ==  bool_signature) {
+		for (cpt = 0; cpt < 1024; cpt ++) {
+			if (
+			    buf [ cpt + 0 ] == 0x4d &&	// M
+			    buf [ cpt + 1 ] == 0x50 &&	// P
+			    buf [ cpt + 2 ] == 0x43 &&	// C
+			    buf [ cpt + 3 ] == 0x4b &&	// K
+			    buf [ cpt + 4 ] == 0x53 &&	// S
+			    buf [ cpt + 5 ] == 0x48	// H
+			    ) {
+			    bool_signature = TRUE;
+			    break;
+			}
+		}
+	}
+	
 	g_free (buf);
 	buf = NULL;
 	
