@@ -8,6 +8,8 @@
  * xcfa - GTK+ implementation of the GNU shell command
  * GNU General Public License
  *
+ *  This file is part of XCFA.
+ * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -79,11 +81,14 @@ gchar		*libutils_remove_temporary_rep (gchar *path_tmprep);
 // 
 void		libcombo_remove (void);
 void		libcombo_alloc (GtkComboBox *p_combo);
+void		libcombo_remove_options (GtkComboBox *p_combo);
 
 // UTF8.C
 // 
 gchar		*utf8_convert_from_utf8 (const char *string);
 gchar		*utf8_convert_to_utf8 (const gchar *string);
+gchar		*utf8_removediacritics( const gchar *str, gssize len );
+gchar		*utf8_eperluette_name( gchar *p_name );
 
 #endif
 
