@@ -151,24 +151,6 @@ void cdaudiotoc_reffresh_list_cd (void)
 	
 	if (var_cd.Adr_Combo_Box == NULL) return;
 	
-	/*
-	if (FALSE == libutils_find_file ("icedax")) {
-		PRINT_FUNC_LF();
-		wininfo_create (
-			_("icedax NOT FOUND"),
-			_("Please, install package [ icedax ]"),
-		  	"");
-		return;
-	}
-	if (FALSE == libutils_find_file ("cdparanoia")) {
-		PRINT_FUNC_LF();
-		wininfo_create (
-			_("cdparanoia NOT FOUND"),
-			_("Please, install package [ cdparanoia ]"),
-		  	"");
-		return;
-	}
-	*/
 	if( FALSE == PrgInit.bool_cdda2wav ) {
 	
 		PRINT_FUNC_LF();
