@@ -363,19 +363,28 @@ gint CdCddb_read_datas (void)
 	if( NULL != ( p_cddb = cddb_new() ) ) {
 		if( SERVER_CDDB_PARAM == Config.ServeurCddb ) {
 			cddb_set_server_name( p_cddb, Config.entry_cddp_server );
-			g_print("With SERVER_CDDB_PARAM      = %s\n", Config.entry_cddp_server);
+			g_print( "With SERVER_CDDB_PARAM       = %s\n", Config.entry_cddp_server);
 		}
 		else {
 			cddb_set_server_name( p_cddb, "freedb.org" );
+			g_print( "With SERVER_CDDB_AUTO        = freedb.org\n" );
 		}
+		g_print( "-------------------------------------------------\n" );
+		g_print( "SET ...\n" );
 		cddb_set_server_port( p_cddb, 888 );
+		g_print( "\tcddb_set_server_port: OK\n" );
 		cddb_cache_disable( p_cddb );
+		g_print( "\tcddb_cache_disable: OK\n" );
 		cddb_set_timeout( p_cddb, 10 );
+		g_print( "\tcddb_set_timeout: OK\n" );
 		cddb_http_disable( p_cddb );
+		g_print( "\tcddb_http_disable: OK\n" );
 	
 		if( NULL != ( p_disc = cddb_disc_new() ) ) {
+			
 			int64_t i_length = 0;
 			
+			g_print( "RECHERCHE CDDB\n" );
 			for( Track = 0; Track < VarCddb . TotalTracks; Track++ ) {
 				cddb_track_t *t = cddb_track_new();
 				cddb_track_set_frame_offset( t, VarCddb . VarStructCddb [ Track ] . Sector );
@@ -383,9 +392,10 @@ gint CdCddb_read_datas (void)
 				const int64_t i_size = ( VarCddb . VarStructCddb [ Track +1 ] . Sector - VarCddb . VarStructCddb [ Track ] . Sector ) *(int64_t)CDDA_DATA_SIZE;
 				i_length += 1000000 * i_size / 44100 / 4;
 			}
-
+			g_print( "\tframe + track: OK\n" );
 			cddb_disc_set_length( p_disc, (int)( i_length / 1000000 ) );
 			cddb_disc_calc_discid( p_disc );
+			g_print( "\tlength + discid: OK\n" );
 			
 			g_print( "-------------------------------------------------\n" );
 			NbrMatchsFound = cddb_query( p_cddb, p_disc );
@@ -556,7 +566,6 @@ gint CdCddb_read_datas (void)
 				BaseIoctl.Cue [ Track ].Title     = g_strdup( VarCddb . VarStructCddb [ Track ] . Title );
 			}
 
-
 			cdcue_print_base_ioctl();
 			
 			cddb_disc_destroy( p_disc );
@@ -581,6 +590,9 @@ void CdCddb_set_toc_to_glist_audio (gint p_etat)
 	gint		NumList;
 	CD_AUDIO	*Audio = NULL;
 	
+	// TODO: DEBUG: manuker: http://forum.ubuntu-fr.org/viewtopic.php?pid=4631891#p4631891
+	PRINT_FUNC_LF();
+
 	// REMOVE DATAS entete
 	CdCddb_init_entete_cd();
 	
@@ -588,7 +600,7 @@ void CdCddb_set_toc_to_glist_audio (gint p_etat)
 	
 	// 
 	switch( p_etat ) {
-	case CDDB_RET_OK :	// OK
+	case CDDB_RET_OK :		// OK
 		EnteteCD.TitleCD     = g_strdup_printf( "%s  -  %s", VarCddb . Artiste, VarCddb . TitleCD );
 		EnteteCD.Artiste     = g_strdup( VarCddb . TitleCD );
 		EnteteCD.TotalTracks = VarCddb . TotalTracks;
@@ -596,21 +608,21 @@ void CdCddb_set_toc_to_glist_audio (gint p_etat)
 		EnteteCD.StrGenre    = g_strdup( VarCddb . StrGenre );
 		EnteteCD.NumYear     = VarCddb . NumYear;
 		EnteteCD.StrYear     = g_strdup( VarCddb . StrYear );
-		EnteteCD.StrDureeCd    = g_strdup( VarCddb . StrDureeCd );
+		EnteteCD.StrDureeCd  = g_strdup( VarCddb . StrDureeCd );
 		break;
 	case CDDB_RET_NO_CONNECT :	// PAS DE CONNEXION WEB
 		EnteteCD.TitleCD     = g_strdup( "Track" );
 		EnteteCD.Title       = g_strdup( "Track" );
 		EnteteCD.Artiste     = g_strdup( "Track" );
 		EnteteCD.TotalTracks = VarCddb . TotalTracks;
-		EnteteCD.StrDureeCd    = g_strdup( VarCddb . StrDureeCd );
+		EnteteCD.StrDureeCd  = g_strdup( VarCddb . StrDureeCd );
 		break;
-	case CDDB_RET_NO_BASE :	// PAS DE BASE POUR CE DISQUE
+	case CDDB_RET_NO_BASE :		// PAS DE BASE POUR CE DISQUE
 		EnteteCD.TitleCD     = g_strdup( "Track" );
 		EnteteCD.Title       = g_strdup( "Track" );
 		EnteteCD.Artiste     = g_strdup( "Track" );
 		EnteteCD.TotalTracks = VarCddb . TotalTracks;
-		EnteteCD.StrDureeCd    = g_strdup( VarCddb . StrDureeCd );
+		EnteteCD.StrDureeCd  = g_strdup( VarCddb . StrDureeCd );
 		break;
 	}
 	
@@ -738,6 +750,16 @@ gboolean CdCddb_read_toc (void)
 	// 
 	Etat = CdCddb_read_datas();
 	
+	// TODO: DEBUG: manuker: http://forum.ubuntu-fr.org/viewtopic.php?pid=4631891#p4631891
+	g_print("Return after call CdCddb_read_datas(): ");
+	switch( Etat ) {
+	case CDDB_RET_OK :		g_print( "CDDB_RET_OK\n" );		break;
+	case CDDB_RET_NO_CD:		g_print( "CDDB_RET_NO_CD\n" );		break;
+	case CDDB_RET_NO_CONNECT :	g_print( "CDDB_RET_NO_CONNECT\n" );	break;
+	case CDDB_RET_NO_BASE :		g_print( "CDDB_RET_NO_BASE\n" );	break;
+	case CDDB_RET_NO_ALLOC :	g_print( "CDDB_RET_NO_ALLOC\n" );	break;
+	}
+	
 	// 
 	CdCddb_set_toc_to_glist_audio( Etat );
 	
