@@ -1,40 +1,33 @@
  /*
- * file      : cd_cue.h
- * project   : xcfa
- * with      : Gtk-2
+ *  file      : cd_cue.h
+ *  project   : xcfa
+ *  with      : Gtk-2
  *
- * copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2011 by Claude Bulin
  *
- * xcfa - GTK+ implementation of the GNU shell command
- * GNU General Public License
+ *  xcfa - GTK+ implementation of the GNU shell command
+ *  GNU General Public License
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * OLD ADRESS:
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- * NEW ADRESS:
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *  This file is part of XCFA.
  * 
+ *  XCFA is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  at your option) any later version.
+ * 
+ *  XCFA is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ * 
+ *  You should have received a copy of the GNU General Public License
+ *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
 #ifndef cd_cue_h
 #define cd_cue_h 1
 
-#include "cdtoc.h"
 
 typedef struct {
 	gint	total;
@@ -106,20 +99,13 @@ typedef struct {
 extern BASE_IOCTL BaseIoctl;
 
 
-void		cdcue_set_base_ioctl (gchar *p_buffer, gint p_TotalTracks);
 void		cdcue_remove_base_ioctl (void);
 void		cdcue_print_base_ioctl (void);
 void		cdcue_alloc_base_ioctl (gint p_taille);
-
-void		cdcue_read_toc_with_cdparanoia (gchar *p_buffer, gint p_TotalTracks);
 void		cdcue_write_cue (void);
 void		cdcue_remove (void);
 gboolean	cdcue_is_alloc (void);
 void		cdcue_make_cue (void);
-void		cdcue_make_cue_with_cdtoc (CD_TOC *CdToc);
-
-void		cdcue_button_cue_creation_from_cd_clicked (void);
-void		cdcue_entry_name_fichier_unique_cue_changed (void);
 void            cdcue_set_BoolExtract (gint p_index, gboolean p_flag);
 
 
