@@ -53,8 +53,12 @@
 
 
 
-gboolean Bool_Changed_Ok = TRUE;
-
+typedef struct {
+	gboolean BoolChangedOk;
+} VAR_CDEXPANDER;
+VAR_CDEXPANDER	VarCdExpander = {
+				TRUE	// BoolChangedOk
+				};
 
 
 // 
@@ -76,14 +80,14 @@ void cdexpander_set_entry_tag_titre_album (void)
 	
 	if (NULL == var_cd.Adr_entry_tag_titre_album) return;
 	if (NULL != (Audio = cdaudio_get_line_selected ())) {
-		Bool_Changed_Ok = FALSE;
+		VarCdExpander.BoolChangedOk = FALSE;
 		gtk_entry_set_text (GTK_ENTRY (var_cd.Adr_entry_tag_titre_album), Audio->tags->Album);
-		Bool_Changed_Ok = TRUE;
+		VarCdExpander.BoolChangedOk = TRUE;
 	}
 	else {
-		Bool_Changed_Ok = FALSE;
+		VarCdExpander.BoolChangedOk = FALSE;
 		gtk_entry_set_text (GTK_ENTRY (var_cd.Adr_entry_tag_titre_album), "");
-		Bool_Changed_Ok = TRUE;
+		VarCdExpander.BoolChangedOk = TRUE;
 	}
 }
 // 
@@ -94,14 +98,14 @@ void cdexpander_set_entry_tag_nom_artiste (void)
 	
 	if (NULL == var_cd.Adr_entry_tag_nom_artiste) return;
 	if (NULL != (Audio = cdaudio_get_line_selected ())) {
-		Bool_Changed_Ok = FALSE;
+		VarCdExpander.BoolChangedOk = FALSE;
 		gtk_entry_set_text (GTK_ENTRY (var_cd.Adr_entry_tag_nom_artiste), Audio->tags->Artist);
-		Bool_Changed_Ok = TRUE;
+		VarCdExpander.BoolChangedOk = TRUE;
 	}
 	else {
-		Bool_Changed_Ok = FALSE;
+		VarCdExpander.BoolChangedOk = FALSE;
 		gtk_entry_set_text (GTK_ENTRY (var_cd.Adr_entry_tag_nom_artiste), "");
-		Bool_Changed_Ok = TRUE;
+		VarCdExpander.BoolChangedOk = TRUE;
 	}
 }
 // 
@@ -111,9 +115,9 @@ void cdexpander_set_spinbutton_tag_piste (void)
 	CD_AUDIO        *Audio = NULL;
 	
 	if (NULL != (Audio = cdaudio_get_line_selected ()) && NULL != var_cd.Adr_spinbutton_tag_piste) {
-		Bool_Changed_Ok = FALSE;
+		VarCdExpander.BoolChangedOk = FALSE;
 		gtk_spin_button_set_value (GTK_SPIN_BUTTON (var_cd.Adr_spinbutton_tag_piste), (gdouble)Audio->tags->IntNumber);
-		Bool_Changed_Ok = TRUE;
+		VarCdExpander.BoolChangedOk = TRUE;
 	}
 }
 // 
@@ -123,9 +127,9 @@ void cdexpander_set_spinbutton_tag_annee (void)
 	CD_AUDIO        *Audio = NULL;
 	
 	if (NULL != (Audio = cdaudio_get_line_selected ()) && NULL != var_cd.Adr_spinbutton_tag_annee) {
-		Bool_Changed_Ok = FALSE;
+		VarCdExpander.BoolChangedOk = FALSE;
 		gtk_spin_button_set_value (GTK_SPIN_BUTTON (var_cd.Adr_spinbutton_tag_annee), (gdouble)Audio->tags->IntYear);
-		Bool_Changed_Ok = TRUE;
+		VarCdExpander.BoolChangedOk = TRUE;
 	}
 }
 // 
@@ -144,14 +148,14 @@ void cdexpander_set_entry_tag_titre_chanson (void)
 	CD_AUDIO            *Audio = NULL;
 	
 	if (NULL != (Audio = cdaudio_get_line_selected ()) && NULL != var_cd.Adr_entry_tag_titre_chanson) {
-		Bool_Changed_Ok = FALSE;
+		VarCdExpander.BoolChangedOk = FALSE;
 		gtk_entry_set_text (GTK_ENTRY (var_cd.Adr_entry_tag_titre_chanson), Audio->tags->Title);
-		Bool_Changed_Ok = TRUE;		
+		VarCdExpander.BoolChangedOk = TRUE;		
 	}
 	else {
-		Bool_Changed_Ok = FALSE;
+		VarCdExpander.BoolChangedOk = FALSE;
 		gtk_entry_set_text (GTK_ENTRY (var_cd.Adr_entry_tag_titre_chanson), "");
-		Bool_Changed_Ok = TRUE;
+		VarCdExpander.BoolChangedOk = TRUE;
 	}
 }
 // 
@@ -161,9 +165,9 @@ void cdexpander_set_new_genre (void)
 	CD_AUDIO            *Audio = NULL;
 
 	if (NULL != (Audio = cdaudio_get_line_selected ()) && NULL != var_cd.Adr_combobox_tag_genre_cd) {
-		Bool_Changed_Ok = FALSE;
+		VarCdExpander.BoolChangedOk = FALSE;
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_cd.Adr_combobox_tag_genre_cd), tags_get_elements_combobox (Audio->tags->IntGenre));
-		Bool_Changed_Ok = TRUE;
+		VarCdExpander.BoolChangedOk = TRUE;
 	}
 }
 // 
@@ -181,27 +185,27 @@ void cdexpander_set_entry_tag_commentaire (void)
 	CD_AUDIO            *Audio = NULL;
 	
 	if (NULL != (Audio = cdaudio_get_line_selected ()) && NULL != var_cd.Adr_entry_tag_commentaire) {
-		Bool_Changed_Ok = FALSE;
+		VarCdExpander.BoolChangedOk = FALSE;
 		gtk_entry_set_text (GTK_ENTRY (var_cd.Adr_entry_tag_commentaire), Audio->tags->Comment);
-		Bool_Changed_Ok = TRUE;		
+		VarCdExpander.BoolChangedOk = TRUE;		
 	}
 	else {
-		Bool_Changed_Ok = FALSE;
+		VarCdExpander.BoolChangedOk = FALSE;
 		gtk_entry_set_text (GTK_ENTRY (var_cd.Adr_entry_tag_commentaire), "");
-		Bool_Changed_Ok = TRUE;
+		VarCdExpander.BoolChangedOk = TRUE;
 	}
 }
 // 
 // 
 void cdexpander_set_entry_tag_titre_fichier_m3u (void)
 {
-	if (FALSE == Bool_Changed_Ok) return;
+	if (FALSE == VarCdExpander.BoolChangedOk) return;
 	if (NULL != var_cd.Adr_entry_tag_titre_fichier) {
-		Bool_Changed_Ok = FALSE;
+		VarCdExpander.BoolChangedOk = FALSE;
 		// m3u
 		// xspf
 		gtk_entry_set_text (GTK_ENTRY (var_cd.Adr_entry_tag_titre_fichier), Config.StringNameFile_m3u_xspf ? Config.StringNameFile_m3u_xspf : "");
-		Bool_Changed_Ok = TRUE;		
+		VarCdExpander.BoolChangedOk = TRUE;		
 	}
 }
 // 
@@ -227,7 +231,7 @@ void on_entry_tag_titre_chanson_changed (GtkEditable *editable, gpointer user_da
 	g_free (str);
 	str = NULL;
 
-	if (FALSE == Bool_Changed_Ok) return;
+	if (FALSE == VarCdExpander.BoolChangedOk) return;
 	if (NULL != (Audio = cdaudio_get_line_selected ())) {
 		g_free (Audio->tags->Title);
 		Audio->tags->Title = NULL;
@@ -247,7 +251,7 @@ void on_entry_tag_titre_album_changed (GtkEditable *editable, gpointer user_data
 	CD_AUDIO     *Audio = NULL;
 	
 	if (NULL == var_cd.Adr_entry_tag_titre_album) return;
-	if (FALSE == Bool_Changed_Ok) return;
+	if (FALSE == VarCdExpander.BoolChangedOk) return;
 	ptr_template = (gchar *)gtk_entry_get_text (GTK_ENTRY (var_cd.Adr_entry_tag_titre_album));
 
 	valid = gtk_tree_model_get_iter_first (var_cd.Adr_Tree_Model, &iter);
@@ -276,7 +280,7 @@ void on_entry_tag_nom_artiste_changed (GtkEditable *editable, gpointer user_data
 	CD_AUDIO     *Audio = NULL;
 	
 	if (NULL == var_cd.Adr_entry_tag_nom_artiste) return;
-	if (FALSE == Bool_Changed_Ok) return;
+	if (FALSE == VarCdExpander.BoolChangedOk) return;
 	ptr_template = (gchar *)gtk_entry_get_text (GTK_ENTRY (var_cd.Adr_entry_tag_nom_artiste));
 	
 	if (TRUE == EnteteCD.BoolMultiArtiste) {
@@ -352,7 +356,7 @@ void on_entry_tag_commentaire_changed (GtkEditable *editable, gpointer user_data
 	CD_AUDIO     *Audio = NULL;
 	
 	if (NULL == var_cd.Adr_entry_tag_commentaire) return;
-	if (FALSE == Bool_Changed_Ok) return;
+	if (FALSE == VarCdExpander.BoolChangedOk) return;
 	ptr_template = (gchar *)gtk_entry_get_text (GTK_ENTRY (var_cd.Adr_entry_tag_commentaire));
 		
 	if (TRUE == EnteteCD.BoolMultiArtiste) {
@@ -437,7 +441,7 @@ void on_spinbutton_tag_piste_value_changed (GtkSpinButton *spinbutton, gpointer
 // 
 void on_entry_tag_titre_fichier_m3u_changed (GtkEditable *editable, gpointer user_data)
 {
-	if (FALSE == Bool_Changed_Ok) return;
+	if (FALSE == VarCdExpander.BoolChangedOk) return;
 	if (NULL != var_cd.Adr_entry_tag_titre_fichier) {
 		g_free (Config.StringNameFile_m3u_xspf);
 		Config.StringNameFile_m3u_xspf = NULL;
