@@ -147,6 +147,7 @@ VAR_CONFIG Config = {
 
 
 
+
 // 
 // 
 void config_print_data (gchar *p_str)
@@ -312,7 +313,7 @@ void config_read (void)
 		
 		config_save ();
 	}
-	
+
 	fp = fopen (PathNameConfig, "r");
 	while (fgets (buf, MAX_CARS, fp) != NULL) {
 		
@@ -420,7 +421,6 @@ void config_read (void)
 		if (FALSE == config_read_value_str (buf, "STRING_PARAM_NAME_LECTEUR_AUDIO",	&Config.StringParamNameLecteurAudio))
 		if (FALSE == config_read_value_str (buf, "STRING_BOOL_FIELD_IS_VISIBLE",	&Config.StringBoolFieldsIsVisible))
 		if (FALSE == config_read_value_str (buf, "STRING_POS_FIELD_IS_NAME",		&Config.StringPosFieldsName))
-		
 		if (FALSE == config_read_value_str (buf, "STRING_ENTRY_CDDP_SERVER",		&Config.entry_cddp_server));
 		
 		buf [ 0 ] = '\0';
@@ -557,7 +557,7 @@ void config_save (void)
 		fprintf (fp, "STRING_EXPANDER_WAVPACK             = %s\n", Config.StringExpanderWavpack ? Config.StringExpanderWavpack : "");
 		
 		fprintf (fp, "SERVER_FREE_CDDB                    = %d\n", Config.ServeurCddb);
-		fprintf (fp, "STRING_ENTRY_CDDP_SERVER            = %s\n", Config.entry_cddp_server != NULL ? Config.entry_cddp_server : "freedb.freedb.org");
+		fprintf (fp, "STRING_ENTRY_CDDP_SERVER            = %s\n", Config.entry_cddp_server != NULL ? Config.entry_cddp_server : "freedb.org");
 		
 		fprintf (fp, "STRING_NAME_FILE_M3U_XSPF           = %s\n", Config.StringNameFile_m3u_xspf ? Config.StringNameFile_m3u_xspf : "");
 		fprintf (fp, "TEMPLATE_TITLE_CDAUDIO              = ");
