@@ -1,33 +1,27 @@
  /*
- * file      : configuser.h
- * project   : xcfa
- * with      : Gtk-2
+ *  file      : configuser.h
+ *  project   : xcfa
+ *  with      : Gtk-2
  *
- * copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2011 by Claude Bulin
  *
- * xcfa - GTK+ implementation of the GNU shell command
- * GNU General Public License
+ *  xcfa - GTK+ implementation of the GNU shell command
+ *  GNU General Public License
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * OLD ADRESS:
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- * NEW ADRESS:
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *  This file is part of XCFA.
  * 
+ *  XCFA is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  at your option) any later version.
+ * 
+ *  XCFA is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ * 
+ *  You should have received a copy of the GNU General Public License
+ *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -79,7 +73,6 @@ typedef struct {
 	gint		NotebookPochette;		// 
 	gint		NotebookOptions;		// 
 	gint		NotebookAppExterns;		// 
-	gboolean	ReadCdByIoctl;			// TRUE = ioctl, FALSE = cdparanoia
 	gint		ExtractCdWith;			// EXTRACT_WITH_CDPARANOIA = 0, EXTRACT_WITH_CDPARANOIA_EXPERT, EXTRACT_WITH_CDDA2WAV	
 	
 	gint		BitrateLameIndice;		// abr .. vbr_new
@@ -143,10 +136,11 @@ typedef struct {
 	gchar		*StringBoolFieldsIsVisible;	// FIELDS DVD,CD,FILES: FALSE or HIDE = 0, TRUE or SHOW = 1
 	gchar		*StringPosFieldsName;		// POS NAME OF DVD,CD,FILES: 0 = LEFT, 1 = CENTER, 2 = RIGHT
 	
+	gint		 NumSelectComboBoxDvd;		// 
 	gint		 NumSelectComboBoxCd;		// 
 	
 	gchar		*entry_cddp_server;		// 
-	gchar		*entry_cddp_port;		// 
+	
 	
 } VAR_CONFIG;
 
