@@ -1,33 +1,27 @@
  /*
- * file      : dvd.c
- * project   : xcfa
- * with      : Gtk-2
+ *  file      : dvd.c
+ *  project   : xcfa
+ *  with      : Gtk-2
  *
- * copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2011 by Claude Bulin
  *
- * xcfa - GTK+ implementation of the GNU shell command
- * GNU General Public License
+ *  xcfa - GTK+ implementation of the GNU shell command
+ *  GNU General Public License
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * OLD ADRESS:
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- * NEW ADRESS:
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *  This file is part of XCFA.
  * 
+ *  XCFA is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  at your option) any later version.
+ * 
+ *  XCFA is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ * 
+ *  You should have received a copy of the GNU General Public License
+ *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -65,6 +59,7 @@
 #include "popup.h"
 #include "win_info.h"
 #include "dvd.h"
+#include "statusbar.h"
 
 
 
@@ -415,37 +410,13 @@ gboolean dvd_get_is_norm_selected (void)
 	gtk_tree_model_foreach (GTK_TREE_MODEL(var_dvd.Adr_Tree_Model), dvd_foreach_is_norm_selected, NULL);
 	return (var_dvd.BoolNormIsSelected);
 }
-// 
-// 
-void dvd_set_flag_buttons_dvd (void)
-{
+/*
 	gchar *str = NULL;
-
-	var_dvd.bool_selected = FALSE;
-	var_dvd.bool_sa = FALSE;
-	var_dvd.total_selected_2ch = 0;
-	var_dvd.total_selected = 0;
-
+	
 	if (GlistDvd == NULL) {
-		gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("button_deplier_dvd")), FALSE);
-		gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("button_replier_dvd")), FALSE);
-		gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("button_extraction_dvd")), FALSE);
-		gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("frame187")), FALSE);
-		gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("frame110")), FALSE);
-		str = g_strdup ("");
-		if (var_dvd.Adr_combobox_normalise_dvd != NULL)
-			gtk_widget_set_sensitive (GTK_WIDGET (GTK_COMBO_BOX (var_dvd.Adr_combobox_normalise_dvd)), FALSE);
+		str = g_strdup (" ");
 	}
 	else {
-		gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("button_deplier_dvd")), TRUE);
-		gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("button_replier_dvd")), TRUE);
-		gtk_tree_model_foreach (GTK_TREE_MODEL(var_dvd.Adr_Tree_Model), dvd_foreach_func_if, NULL);
-		gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("button_extraction_dvd")), var_dvd.total_selected > 0);
-		gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("frame187")), TRUE);
-		gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("frame110")), var_dvd.bool_sa);
-
-		gtk_widget_set_sensitive (GTK_WIDGET (GTK_COMBO_BOX (var_dvd.Adr_combobox_normalise_dvd)), dvd_get_is_norm_selected ());
-		
 		if (var_dvd.bool_err == 0) {
 			str = g_strdup_printf (_("Total selection%s: %d,     2ch: %d"),
 				var_dvd.total_selected > 1 ? _("s") : "",
@@ -458,9 +429,40 @@ void dvd_set_flag_buttons_dvd (void)
 			var_dvd.bool_err --;
 		}
 	}
-	main_puts_statusbar_global (str);
-	g_free (str);
-	str = NULL;
+	StatusBar_set_mess( NOTEBOOK_DVD_AUDIO, _STATUSBAR_SIMPLE_, str );
+	g_free (str);	str = NULL;
+	
+*/
+
+// 
+// 
+void dvd_set_flag_buttons_dvd (void)
+{
+	var_dvd.bool_selected = FALSE;
+	var_dvd.bool_sa = FALSE;
+	var_dvd.total_selected_2ch = 0;
+	var_dvd.total_selected = 0;
+
+	if (GlistDvd == NULL) {
+		gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("button_deplier_dvd")), FALSE);
+		gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("button_replier_dvd")), FALSE);
+		gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("button_extraction_dvd")), FALSE);
+		gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("frame187")), FALSE);
+		gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("frame110")), FALSE);
+		if (var_dvd.Adr_combobox_normalise_dvd != NULL)
+			gtk_widget_set_sensitive (GTK_WIDGET (GTK_COMBO_BOX (var_dvd.Adr_combobox_normalise_dvd)), FALSE);
+	}
+	else {
+		gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("button_deplier_dvd")), TRUE);
+		gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("button_replier_dvd")), TRUE);
+		gtk_tree_model_foreach (GTK_TREE_MODEL(var_dvd.Adr_Tree_Model), dvd_foreach_func_if, NULL);
+		gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("button_extraction_dvd")), var_dvd.total_selected > 0);
+		gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("frame187")), TRUE);
+		gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("frame110")), var_dvd.bool_sa);
+
+		gtk_widget_set_sensitive (GTK_WIDGET (GTK_COMBO_BOX (var_dvd.Adr_combobox_normalise_dvd)), dvd_get_is_norm_selected ());
+	}
+	StatusBar_puts();
 }
 // 
 // 
@@ -858,15 +860,15 @@ gboolean dvd_event (GtkWidget *treeview, GdkEvent *event, gpointer user_data)
 		if (var->EtatNormalise == TRUE)	{
 			switch (dvd_get_value_normalise_dvd ()) {
 			case 0 :
-				main_puts_statusbar_global (_("(Click Droit = Menu) / PEAK-ALBUM: Amplification maximale du volume pour un groupe de fichiers en respectant les ecarts de niveau entre chacun d'eux."));
+				StatusBar_set_mess( NOTEBOOK_DVD_AUDIO, _STATUSBAR_SIMPLE_, _("(Click Droit = Menu) / PEAK-ALBUM: Amplification maximale du volume pour un groupe de fichiers en respectant les ecarts de niveau entre chacun d'eux."));
 				break;
 			case 1 :
-				main_puts_statusbar_global (_("(Click Droit = Menu) / PEAK: Amplification maximale du volume pour chaque de fichier."));
+				StatusBar_set_mess( NOTEBOOK_DVD_AUDIO, _STATUSBAR_SIMPLE_, _("(Click Droit = Menu) / PEAK: Amplification maximale du volume pour chaque de fichier."));
 				break;
 			}
 		}
 		else {
-			main_puts_statusbar_global (_("(Click Droit = Menu) / En attente de selection."));
+			StatusBar_set_mess( NOTEBOOK_DVD_AUDIO, _STATUSBAR_SIMPLE_, _("(Click Droit = Menu) / En attente de selection."));
 		}
 	}
 
@@ -877,12 +879,12 @@ gboolean dvd_event (GtkWidget *treeview, GdkEvent *event, gpointer user_data)
 
 		if (var->name_file && *var->name_file) {
 			str = g_strdup_printf ("%s.wav", var->name_file);
-			main_puts_statusbar_global (str);
+			StatusBar_set_mess( NOTEBOOK_DVD_AUDIO, _STATUSBAR_SIMPLE_, str );
 			g_free (str);
 			str = NULL;
 		}
 		else {
-			main_puts_statusbar_global (" ");
+			StatusBar_set_mess( NOTEBOOK_DVD_AUDIO, _STATUSBAR_SIMPLE_, " " );
 		}
 	}
 
@@ -900,18 +902,19 @@ gboolean dvd_event (GtkWidget *treeview, GdkEvent *event, gpointer user_data)
 			switch (var->EtatChoix) {
 			case _COCHE_ :
 				str = g_strdup (_("En attente de selection. Un click activera la conversion vers 2 canaux."));
-				main_puts_statusbar_global (str);
+				StatusBar_set_mess( NOTEBOOK_DVD_AUDIO, _STATUSBAR_SIMPLE_,  str );
 				break;
 			case _SELECTED_ :
 				/*
 				str = g_strdup_printf (_("Conversion vers %s canaux."), var->StrNumberChannel);
-				main_puts_statusbar_global (str);
+				// main_puts_statusbar_global (str);
+				StatusBar_set_mess( NOTEBOOK_DVD_AUDIO, _STATUSBAR_SIMPLE_,  str );
 				PRINT("SELECTED");
 				*/
 				break;
 			case _CH_2_ :
 				str = g_strdup_printf (_("Conversion vers 2 canaux."));
-				main_puts_statusbar_global (str);
+				StatusBar_set_mess( NOTEBOOK_DVD_AUDIO, _STATUSBAR_SIMPLE_,  str );
 				break;
 			}
 		}
@@ -919,16 +922,16 @@ gboolean dvd_event (GtkWidget *treeview, GdkEvent *event, gpointer user_data)
 			switch (var->EtatChoix) {
 			case _COCHE_ :
 				str = g_strdup (_("En attente de selection. Un click activera la conversion vers 2 canaux."));
-				main_puts_statusbar_global (str);
+				StatusBar_set_mess( NOTEBOOK_DVD_AUDIO, _STATUSBAR_SIMPLE_,  str );
 				break;
 			case _SELECTED_ :
 				str = g_strdup_printf (_("Conversion vers %s canaux."), var->StrNumberChannel);
-				main_puts_statusbar_global (str);
+				StatusBar_set_mess( NOTEBOOK_DVD_AUDIO, _STATUSBAR_SIMPLE_,  str );
 				break;
 			case _CH_2_ :
 				str = g_strdup_printf (
 					_("Conversion vers 2 canaux. Un second click activera la conversion vers %s canaux."), var->StrNumberChannel);
-				main_puts_statusbar_global (str);
+				StatusBar_set_mess( NOTEBOOK_DVD_AUDIO, _STATUSBAR_SIMPLE_, str );
 				break;
 			}
 		}
@@ -942,19 +945,41 @@ gboolean dvd_event (GtkWidget *treeview, GdkEvent *event, gpointer user_data)
 	
 		gtk_tree_model_get (model, &iter, DVD_PIXBUF_COLUMN_PLAY, &Pixbuf, -1);
 		if (Pixbuf == var_dvd.Pixbuf_FileStop) {
-			main_puts_statusbar_global (_("Musique en ecoute."));
+			StatusBar_set_mess( NOTEBOOK_DVD_AUDIO, _STATUSBAR_SIMPLE_, _("Musique en ecoute."));
 		}
 		else if (Pixbuf == var_dvd.Pixbuf_FilePlay) {
-			main_puts_statusbar_global (_("Musique en attente."));
+			StatusBar_set_mess( NOTEBOOK_DVD_AUDIO, _STATUSBAR_SIMPLE_, _("Musique en attente."));
 		}
 		else {
-			main_puts_statusbar_global (" ");
+			StatusBar_set_mess( NOTEBOOK_DVD_AUDIO, _STATUSBAR_SIMPLE_, " ");
 		}
 	}
 	
 	else {
+		gchar *str = NULL;
+	
+		if (GlistDvd == NULL) {
+			str = g_strdup (" ");
+		}
+		else {
+			if (var_dvd.bool_err == 0) {
+				str = g_strdup_printf (_("Total selection%s: %d,     2ch: %d"),
+					var_dvd.total_selected > 1 ? _("s") : "",
+					var_dvd.total_selected,
+					var_dvd.total_selected_2ch
+					);
+			}
+			else {
+				str = g_strdup(_("<b>Ce fichier ne peut etre extrait !</b>"));
+				var_dvd.bool_err --;
+			}
+		}
+		StatusBar_set_mess( NOTEBOOK_DVD_AUDIO, _STATUSBAR_SIMPLE_, str );
+		g_free (str);	str = NULL;
+		
 		dvd_set_flag_buttons_dvd ();
 	}
+	StatusBar_puts(  );
 
 	return (FALSE);
 }
@@ -1226,12 +1251,13 @@ void on_combobox_peripherique_dvd_realize (GtkWidget *widget, gpointer user_data
 		List = g_list_next(List);
 	}
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Fichier structure DVD"));
-	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 0);
+	if( Config.NumSelectComboBoxDvd < 0 ) Config.NumSelectComboBoxDvd = 0;
+	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), Config.NumSelectComboBoxDvd);
 	var_dvd.Adr_ComboBox_Reader = GTK_COMBO_BOX (widget);
 }
 // 
 // 
-void *dvd_pthread_reffresh_list (void *data)
+void  dvd_pthread_reffresh_list (void *data)
 {
 	var_dvd.bool_end_pthread = FALSE;
 	var_dvd.bool_read_dvd = TRUE;
@@ -1263,11 +1289,9 @@ static gint dvd_timeout (gpointer data)
 
 		if (var_dvd.bool_halt == TRUE) {
 			// main_puts_statusbar_global (_("Arret par l'utilisateur"));
-
 		}
 		else {
 			if (var_dvd.bool_read_dvd == TRUE) {
-				
 				dvd_affiche_list ();
 				gtk_tree_view_expand_all ( (GtkTreeView *)var_dvd.Adr_TreeView);
 			}
@@ -1276,7 +1300,10 @@ static gint dvd_timeout (gpointer data)
 		dvd_set_flag_buttons_dvd ();
 
 		if (var_dvd.bool_read_dvd == FALSE) {
-			// main_puts_statusbar_global (_("Le DVD est absent du lecteur."));
+			StatusBar_set_mess( NOTEBOOK_DVD_AUDIO, _STATUSBAR_SIMPLE_,  _("Le DVD est absent du lecteur."));
+		}
+		else {
+			StatusBar_set_mess( NOTEBOOK_DVD_AUDIO, _STATUSBAR_SIMPLE_,  "" );
 		}
 
 		gtk_timeout_remove (var_dvd.Handler_Timeout);
@@ -1306,6 +1333,7 @@ void dvd_reffresh_list_dvd_action (void)
 	dvd_remove_GtkTree ();
 
 	var_dvd.PathDvd = scan_get_text_combo_cd (_DVD_);
+	g_print("---------------> var_dvd.PathDvd = %s\n",var_dvd.PathDvd );
 	
 	WindScan_open (_("Scan ..."), WINDSCAN_PULSE);
 	
@@ -1314,7 +1342,7 @@ void dvd_reffresh_list_dvd_action (void)
 	var_dvd.bool_end_pthread = FALSE;
 	var_dvd.Handler_Timeout = gtk_timeout_add (100, dvd_timeout, 0);
 	pthread_create (&nmr_tid, NULL ,(void *)dvd_pthread_reffresh_list, (void *)NULL);
-	pthread_detach (nmr_tid);
+	// pthread_detach (nmr_tid);
 }
 // 
 // 
@@ -1323,14 +1351,16 @@ void dvd_reffresh_list_directory_dvd (gchar *path)
 	gchar	*Ptr = NULL;
 	
 	var_dvd.from.bool_dvd = FALSE;
-
-	g_free (var_dvd.from.path);
-	var_dvd.from.path = NULL;
+	if( NULL != var_dvd.from.path ) {
+		g_free (var_dvd.from.path);	var_dvd.from.path = NULL;
+	}
 	var_dvd.from.path = g_strdup (path);
 
-	g_free (Config.PathChoiceFileDVD);
-	Config.PathChoiceFileDVD = NULL;
+	if( NULL != Config.PathChoiceFileDVD ) {
+		g_free (Config.PathChoiceFileDVD);	Config.PathChoiceFileDVD = NULL;
+	}
 	Config.PathChoiceFileDVD = g_strdup (path);
+	
 	if (NULL != (Ptr = strrchr (Config.PathChoiceFileDVD, '/'))) {
 		*Ptr = '\0';
 	}
@@ -1625,7 +1655,10 @@ void on_button_eject_dvd_clicked (GtkButton *button, gpointer user_data)
 // 
 void on_combobox_peripherique_dvd_changed (GtkComboBox *combobox, gpointer user_data)
 {
-	dvd_reffresh_list_dvd ();
+	if( NULL != var_dvd.Adr_ComboBox_Reader ) {
+		Config.NumSelectComboBoxDvd = gtk_combo_box_get_active (GTK_COMBO_BOX (var_dvd.Adr_ComboBox_Reader));
+		dvd_reffresh_list_dvd ();
+	}
 }
 // 
 // 
@@ -1663,17 +1696,3 @@ void dvd_from_popup (TYPE_SET_FROM_POPUP_DVD TypeSetFromPopup, gboolean EtatNorm
 	}
 }
 
-
-
-// 
-// PREFERENCES ET APPLICATIONS EXTERNES
-// 
-
-void on_checkbutton_activate_journal_realize (GtkWidget *widget, gpointer user_data){}
-void on_checkbutton_activate_journal_clicked (GtkButton *button, gpointer user_data){}
-void on_button_remove_journal_realize (GtkWidget *widget, gpointer user_data){}
-void on_button_remove_journal_clicked (GtkButton *button, gpointer user_data){}
-void on_button_dossier_journal_realize (GtkWidget *widget, gpointer user_data){}
-void on_button_dossier_journal_clicked (GtkButton *button, gpointer user_data){}
-
-
