@@ -1,33 +1,27 @@
  /*
- * file      : file_action.c
- * project   : xcfa
- * with      : Gtk-2
+ *  file      : file_action.c
+ *  project   : xcfa
+ *  with      : Gtk-2
  *
- * copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2011 by Claude Bulin
  *
- * xcfa - GTK+ implementation of the GNU shell command
- * GNU General Public License
+ *  xcfa - GTK+ implementation of the GNU shell command
+ *  GNU General Public License
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * OLD ADRESS:
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- * NEW ADRESS:
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *  This file is part of XCFA.
  * 
+ *  XCFA is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  at your option) any later version.
+ * 
+ *  XCFA is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ * 
+ *  You should have received a copy of the GNU General Public License
+ *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -86,6 +80,7 @@
 #include "replaygain.h"
 #include "win_scan.h"
 #include "normalise.h"
+#include "popup_systray.h"
 
 
 /*
@@ -186,6 +181,7 @@ static gint fileaction_timeout (gpointer data)
 	    FALSE == FileAction.bool_ReplaygainApply &&
 	    FALSE == FileAction.bool_trash) {
 		
+		PopupSystray_set_BoolMainAction (FALSE);
 		WindScan_close ();
 		gtk_timeout_remove (FileAction.handler_timeout);
 	}
@@ -236,6 +232,8 @@ void fileaction_choice (void)
 	// g_print("FileAction.bool_conversion         = %s\n", FileAction.bool_conversion ? "TRUE" : "FALSE");
 	// g_print("FileAction.bool_ReplaygainApply    = %s\n", FileAction.bool_ReplaygainApply ? "TRUE" : "FALSE");
 	
+	PopupSystray_set_BoolMainAction (TRUE);
+	
 	FileAction.handler_timeout = gtk_timeout_add (150, fileaction_timeout, 0);
 }
 
