@@ -282,9 +282,6 @@ void fileanalyze_recherche_recursive (gchar *Directory)
 // 
 TYPE_FILE_IS fileanalyze_is_valid (gchar *PathName, TYPE_FILESELECTION p_TypeFileselection)
 {
-	/*gchar	*TabFileAll[]    = {".WAV",".MP3",".OGG",".FLAC",".APE",".WV",".M4A",".AAC",".MPC",".WMA",".SHN",".RM",".DTS",".AIF",".AIFF",".AIFC",".CUE",""};
-	gchar	*TabFileWav[]    = {".WAV",""};
-	gchar	*TabFileMp3Ogg[] = {".MP3",".OGG", ""};*/
 	gint		TypeTabFileAll[] = {
 					FILE_IS_FLAC,
 					FILE_IS_WAV,
