@@ -1,33 +1,27 @@
  /*
- * file      : file_mp3ogg_conv.c
- * project   : xcfa
- * with      : Gtk-2
+ *  file      : file_mp3ogg_conv.c
+ *  project   : xcfa
+ *  with      : Gtk-2
  *
- * copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2011 by Claude Bulin
  *
- * xcfa - GTK+ implementation of the GNU shell command
- * GNU General Public License
+ *  xcfa - GTK+ implementation of the GNU shell command
+ *  GNU General Public License
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * OLD ADRESS:
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- * NEW ADRESS:
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *  This file is part of XCFA.
  * 
+ *  XCFA is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  at your option) any later version.
+ * 
+ *  XCFA is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ * 
+ *  You should have received a copy of the GNU General Public License
+ *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -64,6 +58,7 @@
 #include "prg_init.h"
 #include "win_scan.h"
 #include "win_info.h"
+#include "popup_systray.h"
 #include "file.h"
 
 
@@ -283,6 +278,8 @@ static gint filemp3oggconv_timeout (gpointer data)
 			conv.TmpRep  = libutils_remove_temporary_rep (conv.TmpRep);
 		}
 
+		PopupSystray_set_BoolMainAction (FALSE);
+
 		gtk_timeout_remove (conv.handler_timeout_conv);
 		WindScan_close ();
 		FileMp3Ogg_set_flag_buttons ();
@@ -412,6 +409,8 @@ void filemp3oggconv_apply_regul_mp3ogg_by_conv (void)
 		WindScan_open ("Conversions bitrate", WINDSCAN_PULSE);
 		WindScan_set_label ("<b><i>Conversions bitrate ...</i></b>");
 	
+		PopupSystray_set_BoolMainAction (TRUE);
+	
 		conv_reset_struct (WindScan_close_request);
 		filemp3oggconv_set_flags_before_conversion ();
 		conv.bool_thread_conv = TRUE;
