@@ -1093,13 +1093,24 @@ static void FileTags_drag_data_drop (GtkWidget *widget,
 		if ((path = list->data)) {
 			gtk_tree_model_get_iter (model, &iter, path);
 			gtk_tree_model_get (var_file_tags.Adr_Tree_Model, &iter, COLUMN_FILETAGS_POINTER_STRUCT, &detail, -1);
-			/*g_print ("detail->namefile = %s\n", detail->namefile);*/
-			text = g_strdup (detail->namefile);
-			gtk_selection_data_set (selection_data,
-						GDK_SELECTION_TYPE_STRING,
-						8,	/* 8 bits per character. */
-						(const guchar *)text,
-						strlen(text)
+			
+			// DEBUG DRAG AND DROP
+			// [ Tue, 03 May 2011 17:39:08 +0200 ]
+			// XCFA-4.1.0
+			// -----------------------------------------------------------
+			// OLD CODE:
+			// 	text = g_strdup( detail->namefile );
+			// NEW_CODE:
+			text = g_strdup_printf( "file://%s", detail->namefile );
+			
+			gdk_drag_status (dc, GDK_ACTION_COPY, t); 
+
+			gtk_selection_data_set( selection_data,
+						// GDK_SELECTION_TYPE_STRING,
+						selection_data->target,
+						8,
+						(guchar *)text,
+						strlen( text )
 						);
 			g_free (text);
 			text = NULL;
