@@ -500,6 +500,38 @@ void AnalyseCommandLine_set_argv (int argc, gchar *argv[])
 	g_free (str_current_dir);
 	str_current_dir = NULL;
 }
+/*
+void
+xcfa_init(int argc, char *argv[] )
+{
+	gint	 i;
+	gchar	*str_current_dir = NULL;
+	FILE	*fp = NULL;
+	
+	if (optind < argc) {
+		str_current_dir = g_get_current_dir ();
+		fp = fopen ("/home/cat/xcfa.txt", "a");
+		for (i = optind; i < argc; i++)
+		{
+			if (argv[i][0] == '/') {
+
+				fprintf (fp, "%s\n", argv[ i ]);
+			}
+			else {
+				gchar *str = NULL;
+				
+				str = g_strdup_printf ("%s/%s", str_current_dir, argv[i]);
+				fprintf (fp, "%s\n", str);
+				g_free (str);
+				str = NULL;
+			}
+		}
+		fclose (fp);
+	}
+	g_free (str_current_dir);
+	str_current_dir = NULL;
+}
+*/
 /* gint main (gint argc, gchar *argv[], gchar **envp)
  *
  * argc  designe le nombre d'arguments transmis au moment du lancement de l'executable
@@ -516,6 +548,7 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	gchar	*PackageVersion = NULL;
 
 	// g_mem_set_vtable (glib_mem_profiler_table);
+	// xcfa_init(argc, &argv[0]);
 	
 	if (TRUE == process_exist_file ()) {
 		
@@ -533,7 +566,6 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 		// process_goto_timeout ();
 	}
 	
-	
 	g_print ("%s :: %s (line = %d)\n", __FILE__, __FUNCTION__, __LINE__);
 	g_print ("\n");
 	g_print ("***************************\n");
