@@ -128,6 +128,10 @@ static 	gchar *str_val_mode[] = {
 	};
 static gchar StrLame[ 100 ];
 
+gboolean bool_do_enter_options_mp3 = TRUE;
+
+
+
 
 // 
 // 
@@ -243,6 +247,7 @@ void on_combobox_lame_abr_cbr_vbr_changed (GtkComboBox *combobox, gpointer user_
 	if ((ind = gtk_combo_box_get_active (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_abr_cbr_vbr))) < 0) return;
 	Config.BitrateLameIndice = ind;
 	// libcombo_alloc (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate));
+	bool_do_enter_options_mp3 = FALSE;
 	libcombo_remove_options (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate));
 	
 	switch (Config.BitrateLameIndice) {
@@ -323,6 +328,7 @@ void on_combobox_lame_abr_cbr_vbr_changed (GtkComboBox *combobox, gpointer user_
 		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "V9");
 		break;
 	}
+	bool_do_enter_options_mp3 = TRUE;
 	gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), Config.TabBitrateLame [ Config.BitrateLameIndice ]);
 	if (NULL != var_options.Adr_Widget_Lame_Mode)
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_Mode), Config.TabModeLame [ Config.BitrateLameIndice ]);
@@ -338,7 +344,8 @@ void on_combobox_lame_type_bitrate_changed (GtkComboBox *combobox, gpointer user
 {
 	gint ind;
 	
-	if (var_options.Adr_Widget_Lame_abr_cbr_vbr == NULL || var_options.Adr_Widget_Lame_bitrate == NULL) return;
+	if( FALSE == bool_do_enter_options_mp3 ) return;
+	if (var_options.Adr_Widget_Lame_abr_cbr_vbr == NULL && var_options.Adr_Widget_Lame_bitrate == NULL) return;
 	if ((ind = gtk_combo_box_get_active (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate))) < 0) return;
 	Config.TabBitrateLame [ Config.BitrateLameIndice ] = ind;
 	OptionsInternal_set_datas_interne (COLOR_LAME_DEBIT, var_options.Adr_label_lame_mp3, LAME_WAV_TO_MP3);
