@@ -1,33 +1,27 @@
  /*
  * file    : poche_evnt.h
- * project   : xcfa
- * with      : Gtk-2
+ *  project   : xcfa
+ *  with      : Gtk-2
  *
- * copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2011 by Claude Bulin
  *
- * xcfa - GTK+ implementation of the GNU shell command
- * GNU General Public License
+ *  xcfa - GTK+ implementation of the GNU shell command
+ *  GNU General Public License
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * OLD ADRESS:
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- * NEW ADRESS:
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *  This file is part of XCFA.
  * 
+ *  XCFA is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  at your option) any later version.
+ * 
+ *  XCFA is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ * 
+ *  You should have received a copy of the GNU General Public License
+ *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -334,7 +328,8 @@ void pocheevnt_table_add_images (void)
 			gtk_container_set_border_width (GTK_CONTAINER (gl->togglebutton), 5);
 
 			/* image */
-			gl->image = create_pixmap (WindMain, NULL);
+			// gl->image = create_pixmap (WindMain, NULL);
+			gl->image = gtk_image_new ();
 			gtk_widget_show (gl->image);
 			gtk_container_add (GTK_CONTAINER (gl->togglebutton), gl->image);
 			gtk_image_set_from_file (GTK_IMAGE (gl->image), gl->name_png);
@@ -377,7 +372,6 @@ void pocheevnt_table_add_images (void)
 		}
 		list = g_list_next (list);
 	}
-	/* while (gtk_events_pending()) gtk_main_iteration(); */
 }
 // 
 // 
@@ -463,7 +457,6 @@ gboolean on_eventbox_image_preview_event (GtkWidget *widget, GdkEvent *event, gp
 	}
 	if (poche.bool_redraw == TRUE) {
 		cursor_set_watch ();
-		/* while (gtk_events_pending()) gtk_main_iteration(); */
 		return (FALSE);
 	}
 	if (cursor_get_watch () == TRUE) {
@@ -1813,7 +1806,6 @@ void pocheevnt_init (void)
 {
 	gchar   *LineCommand = NULL;
 
-	/* while (gtk_events_pending()) gtk_main_iteration(); */
 	pochedraw_get_grille_img ();
 
 	/* Creation dossiers */
@@ -1876,7 +1868,7 @@ void pocheevnt_init (void)
 			pthread_create (&pochevent_event.nmr_tid, NULL ,(void *)pocheevnt_initialisation_thread, (void *)NULL);
 
 			// DEBUG
-			pthread_detach (pochevent_event.nmr_tid);
+			// pthread_detach (pochevent_event.nmr_tid);
 		}
 	}
 	*/
@@ -2065,7 +2057,6 @@ static gint poche_handler_timeout_spinbutton (gpointer data)
 		gtk_timeout_remove (pochevent_event.timeout);
 cursor_set_watch ();
 pocheevnt_set_flag (FALSE);
-		/* while (gtk_events_pending()) gtk_main_iteration(); */
 		bool_button_press = FALSE;
 		bool_button_release = FALSE;
 		pochevent_event.EndTimeout = TRUE;
@@ -2230,7 +2221,6 @@ void pocheevnt_action_popup (gboolean is_recto, gint val_action)
 	poche.bool_redraw = TRUE;
 	cursor_set_watch ();
 	pocheevnt_set_flag (FALSE);
-	/* while (gtk_events_pending()) gtk_main_iteration(); */
 	pochegen_gen_code_postscript ();
 	pochegen_affiche_image ();
 	pocheevnt_set_flag_buttons_recto ();
@@ -2882,7 +2872,7 @@ void on_button_get_title_cdaudio_clicked (GtkButton *button, gpointer user_data)
 void on_button_importation_titre_cd_clicked (GtkButton *button, gpointer user_data)
 {
 	GtkTextBuffer	*Buf = NULL;
-	AUDIO		*Audio = NULL;
+	CD_AUDIO	*Audio = NULL;
 	GList		*List = NULL;
 	gchar		*ptr = NULL;
 	
@@ -2908,7 +2898,7 @@ void on_button_importation_titre_cd_clicked (GtkButton *button, gpointer user_da
 	gtk_text_buffer_insert_at_cursor (Buf, "\n", -1);
 	List = g_list_first (EnteteCD.GList_Audio_cd);
 	while (List) {
-		if ((Audio = (AUDIO *)List->data)) {
+		if ((Audio = (CD_AUDIO *)List->data)) {
 			
 			gchar *Str = NULL;
 			
@@ -2955,7 +2945,7 @@ gboolean pocheevnt_get_load_images_init_xcfa (void)
 // 
 void on_combobox_generate_ps_pdf_realize (GtkWidget *widget, gpointer user_data)
 {
-	libcombo_alloc (GTK_COMBO_BOX (widget));
+	// libcombo_alloc (GTK_COMBO_BOX (widget));
 	
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Choix:"));
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("     Generation fichier PostScript"));
