@@ -1,33 +1,27 @@
  /*
- * file      : poche_code.c
- * project   : xcfa
- * with      : Gtk-2
+ *  file      : popup.c
+ *  project   : xcfa
+ *  with      : Gtk-2
  *
- * copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2011 by Claude Bulin
  *
- * xcfa - GTK+ implementation of the GNU shell command
- * GNU General Public License
+ *  xcfa - GTK+ implementation of the GNU shell command
+ *  GNU General Public License
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * OLD ADRESS:
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- * NEW ADRESS:
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *  This file is part of XCFA.
  * 
+ *  XCFA is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  at your option) any later version.
+ * 
+ *  XCFA is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ * 
+ *  You should have received a copy of the GNU General Public License
+ *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
  
  
@@ -65,7 +59,7 @@
 
 typedef struct {
 	DETAIL      *detail;
-	AUDIO       *Audio;
+	CD_AUDIO    *Audio;
 	TYPE_FILE_IS type_file_is;
 	
 	/*GdkPixbuf   *Image_dbfs_no;
@@ -630,7 +624,7 @@ void popup_normalise_dvd (void)
 // 
 // 
 
-void popup_cd (AUDIO *Audio, TYPE_FILE_IS TypeFileIs)
+void popup_cd (CD_AUDIO *Audio, TYPE_FILE_IS TypeFileIs)
 {
 	VarPopup.detail       = (DETAIL *)NULL;
 	VarPopup.type_file_is = TypeFileIs;
@@ -753,3 +747,5 @@ void popup_for_pocheevent (gboolean bool_recto)
 	gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, 3, 0);
 }
 
+
+
