@@ -43,6 +43,7 @@
 #endif
 
 #include "global.h"
+#include "configuser.h"
 #include "popup_systray.h"
 
 
@@ -79,29 +80,20 @@ void PopupSystray_set_BoolMainAction (gboolean p_BoolMainAction)
 // 
 void PopupSystray_show_hide (void)
 {
-/*
-void gtk_window_set_screen( GtkWindow *window, GdkScreen *screen );
-GdkScreen *gtk_widget_get_screen( GtkWidget *widget );
-*/
-	/*
-	if (TRUE == VarPopupSystray.BoolMainShow) {
+	static GdkScreen *screen;
+
+	if( GTK_WIDGET_FLAGS(WindMain) & GTK_VISIBLE ){
+		gtk_window_get_position( GTK_WINDOW(WindMain), &Config.WinPos_X, &Config.WinPos_Y);
+		screen = gtk_window_get_screen( GTK_WINDOW(WindMain) );
+		gtk_widget_hide( GTK_WIDGET(WindMain) );
 		VarPopupSystray.BoolMainShow = FALSE;
-		gtk_widget_hide_all( WindMain );
-	}
-	else if (FALSE == VarPopupSystray.BoolMainShow) {
+	} else {
+		gtk_window_set_screen( GTK_WINDOW(WindMain), screen);
+		gtk_window_move( GTK_WINDOW(WindMain), Config.WinPos_X, Config.WinPos_Y);
+		gtk_widget_show( GTK_WIDGET (WindMain) );
+		gtk_window_present( GTK_WINDOW(WindMain) );
+		gtk_window_deiconify( GTK_WINDOW(WindMain) );
 		VarPopupSystray.BoolMainShow = TRUE;
-		gtk_widget_show_all( WindMain );
-	}
-	g_print("VarPopupSystray.BoolMainShow = %s\n",VarPopupSystray.BoolMainShow ? "Show->TRUE" : "Hide->FALSE");
-	*/
-	if(GTK_WIDGET_FLAGS (WindMain) & GTK_VISIBLE){
-		gtk_widget_hide( WindMain );
-		VarPopupSystray.BoolMainShow = FALSE;
-		gtk_widget_set_visible(WindMain, VarPopupSystray.BoolMainShow);
-	}else{
-		gtk_widget_show( WindMain );
-		VarPopupSystray.BoolMainShow = TRUE;
-		gtk_widget_set_visible(WindMain, VarPopupSystray.BoolMainShow);
 	}
 }
 // 
