@@ -1,33 +1,27 @@
  /*
- * file      : prg_init.c
- * project   : xcfa
- * with      : Gtk-2
+ *  file      : prg_init.c
+ *  project   : xcfa
+ *  with      : Gtk-2
  *
- * copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2011 by Claude Bulin
  *
- * xcfa - GTK+ implementation of the GNU shell command
- * GNU General Public License
+ *  xcfa - GTK+ implementation of the GNU shell command
+ *  GNU General Public License
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * OLD ADRESS:
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- * NEW ADRESS:
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *  This file is part of XCFA.
  * 
+ *  XCFA is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  at your option) any later version.
+ * 
+ *  XCFA is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ * 
+ *  You should have received a copy of the GNU General Public License
+ *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -70,6 +64,7 @@ enum
 {
 	PRGEXT_NAME = 0,
 	PRGEXT_STATUS,
+	PRGEXT_PAQUAGE,
 	PRGEXT_COMMENT,
 	PRGEXT_NUM_COLUMN,
 	PRGEXT_TOTAL_COLUMN
@@ -92,8 +87,6 @@ TABLEAU_PRG_EXTERN TableauPrgExtern [ NMR_MAX_TABLEAU ] = {
 "",								// NAME2
 "",								// NAME3
 &PrgInit.bool_a52dec,						// FOUND
-"",								// DEPOTDEBIAN_64
-"",								// DEPOTDEBIAN_32
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
 NULL},								// DESCRIPTION
@@ -104,8 +97,6 @@ NULL},								// DESCRIPTION
 "",								// NAME2
 "",								// NAME3
 &PrgInit.bool_aacplusenc,					// FOUND
-"aacplusenc_0.17.3_amd64.deb",					// DEPOTDEBIAN_64
-"aacplusenc_0.17.3_i386.deb",					// DEPOTDEBIAN_32
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
 NULL},								// DESCRIPTION
@@ -116,8 +107,6 @@ NULL},								// DESCRIPTION
 "",								// NAME2
 "",								// NAME3
 &PrgInit.bool_cdparanoia,					// FOUND
-"",								// DEPOTDEBIAN_64
-"",								// DEPOTDEBIAN_32
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
 NULL},								// DESCRIPTION
@@ -128,8 +117,6 @@ NULL},								// DESCRIPTION
 "checkmp3",							// NAME2
 "mp3_check",							// NAME3
 &PrgInit.bool_checkmp3,						// FOUND
-"",								// DEPOTDEBIAN_64
-"",								// DEPOTDEBIAN_32
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
 NULL},								// DESCRIPTION
@@ -140,8 +127,6 @@ NULL},								// DESCRIPTION
 "",								// NAME2
 "",								// NAME3
 &PrgInit.bool_convert,						// FOUND
-"",								// DEPOTDEBIAN_64
-"",								// DEPOTDEBIAN_32
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
 NULL},								// DESCRIPTION
@@ -152,8 +137,6 @@ NULL},								// DESCRIPTION
 "",								// NAME2
 "",								// NAME3
 &PrgInit.bool_cuetools,						// FOUND
-"",								// DEPOTDEBIAN_64
-"",								// DEPOTDEBIAN_32
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
 NULL},								// DESCRIPTION
@@ -164,8 +147,6 @@ NULL},								// DESCRIPTION
 "",								// NAME2
 "",								// NAME3
 &PrgInit.bool_faac,						// FOUND
-"",								// DEPOTDEBIAN_64
-"",								// DEPOTDEBIAN_32
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
 NULL},								// DESCRIPTION
@@ -176,8 +157,6 @@ NULL},								// DESCRIPTION
 "faad2",							// NAME2
 "",								// NAME3
 &PrgInit.bool_faad,						// FOUND
-"",								// DEPOTDEBIAN_64
-"",								// DEPOTDEBIAN_32
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
 NULL},								// DESCRIPTION
@@ -188,8 +167,6 @@ NULL},								// DESCRIPTION
 "",								// NAME2
 "",								// NAME3
 &PrgInit.bool_flac,						// FOUND
-"",								// DEPOTDEBIAN_64
-"",								// DEPOTDEBIAN_32
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
 NULL},								// DESCRIPTION
@@ -200,8 +177,6 @@ NULL},								// DESCRIPTION
 "cdda2wav",							// NAME2
 "",								// NAME3
 &PrgInit.bool_cdda2wav,						// FOUND
-"",								// DEPOTDEBIAN_64
-"",								// DEPOTDEBIAN_32
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
 NULL},								// DESCRIPTION
@@ -212,8 +187,6 @@ NULL},								// DESCRIPTION
 "",								// NAME2
 "",								// NAME3
 &PrgInit.bool_lame,						// FOUND
-"",								// DEPOTDEBIAN_64
-"",								// DEPOTDEBIAN_32
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
 NULL},								// DESCRIPTION
@@ -224,8 +197,6 @@ NULL},								// DESCRIPTION
 "",								// NAME2
 "",								// NAME3
 &PrgInit.bool_lsdvd,						// FOUND
-"",								// DEPOTDEBIAN_64
-"",								// DEPOTDEBIAN_32
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
 NULL},								// DESCRIPTION
@@ -237,24 +208,10 @@ NULL},								// DESCRIPTION
 "",								// NAME2
 "",								// NAME3
 &PrgInit.bool_ape,						// FOUND
-"",								// DEPOTDEBIAN_64
-"",								// DEPOTDEBIAN_32
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
 NULL},								// DESCRIPTION
-/*
-{"mac",								// PACKAGEDEBIAN_64
-"mac",								// PACKAGEDEBIAN_32
-"mac",								// NAME1
-"",								// NAME2
-"",								// NAME3
-&PrgInit.bool_ape,						// FOUND
-"mac_3.99-4_amd64.deb",						// DEPOTDEBIAN_64
-"mac_3.99-4_i386.deb",						// DEPOTDEBIAN_32
-NULL,								// NAME TREE-VIEW
-NULL,								// PIXBUF TREE-VIEW
-NULL},								// DESCRIPTION
-*/
+
 // ADD TO amd64 and i386
 {"musepack-tools",						// PACKAGEDEBIAN_64
 "musepack-tools",						// PACKAGEDEBIAN_32
@@ -262,8 +219,6 @@ NULL},								// DESCRIPTION
 "mppdec",							// NAME2
 "mpc123",							// NAME3
 &PrgInit.bool_mpc123_mppdec,					// FOUND
-"",								// DEPOTDEBIAN_64
-"",								// DEPOTDEBIAN_32
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
 NULL},								// DESCRIPTION
@@ -274,46 +229,16 @@ NULL},								// DESCRIPTION
 "mppenc",							// NAME2
 "",								// NAME3
 &PrgInit.bool_mppenc,						// FOUND
-"",								// DEPOTDEBIAN_64
-"",								// DEPOTDEBIAN_32
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
 NULL},								// DESCRIPTION
 
-
-/*
-{"mpc123",							// PACKAGEDEBIAN_64
-"mpc123",							// PACKAGEDEBIAN_32
-"mppdec",							// NAME1
-"mpc123",							// NAME2
-"",								// NAME3
-&PrgInit.bool_mpc123_mppdec,					// FOUND
-"",								// DEPOTDEBIAN_64
-"musepack-decoder_7.1.95z67-2_i386.deb",			// DEPOTDEBIAN_32
-NULL,								// NAME TREE-VIEW
-NULL,								// PIXBUF TREE-VIEW
-NULL},								// DESCRIPTION
-
-{"mppenc",							// PACKAGEDEBIAN_64
-"mppenc",							// PACKAGEDEBIAN_32
-"mppenc",							// NAME1
-"",								// NAME2
-"",								// NAME3
-&PrgInit.bool_mppenc,						// FOUND
-"",								// DEPOTDEBIAN_64
-"mppenc_1.16-4_i386.deb",					// DEPOTDEBIAN_32
-NULL,								// NAME TREE-VIEW
-NULL,								// PIXBUF TREE-VIEW
-NULL},								// DESCRIPTION
-*/
 {"mplayer",							// PACKAGEDEBIAN_64
 "mplayer",							// PACKAGEDEBIAN_32
 "mplayer",							// NAME1
 "",								// NAME2
 "",								// NAME3
 &PrgInit.bool_mplayer,						// FOUND
-"",								// DEPOTDEBIAN_64
-"",								// DEPOTDEBIAN_32
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
 NULL},								// DESCRIPTION
@@ -324,8 +249,6 @@ NULL},								// DESCRIPTION
 "",								// NAME2
 "",								// NAME3
 &PrgInit.bool_mp3gain,						// FOUND
-"",								// DEPOTDEBIAN_64
-"",								// DEPOTDEBIAN_32
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
 NULL},								// DESCRIPTION
@@ -336,8 +259,6 @@ NULL},								// DESCRIPTION
 "",								// NAME2
 "",								// NAME3
 &PrgInit.bool_mpg321,						// FOUND
-"",								// DEPOTDEBIAN_64
-"",								// DEPOTDEBIAN_32
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
 NULL},								// DESCRIPTION
@@ -348,8 +269,6 @@ NULL},								// DESCRIPTION
 "",								// NAME2
 "",								// NAME3
 &PrgInit.bool_mp3splt,						// FOUND
-"",								// DEPOTDEBIAN_64
-"",								// DEPOTDEBIAN_32
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
 NULL},								// DESCRIPTION
@@ -360,8 +279,6 @@ NULL},								// DESCRIPTION
 "normalize",							// NAME2
 "",								// NAME3
 &PrgInit.bool_normalize,					// FOUND
-"",								// DEPOTDEBIAN_64
-"",								// DEPOTDEBIAN_32
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
 NULL},								// DESCRIPTION
@@ -372,8 +289,6 @@ NULL},								// DESCRIPTION
 "notify-send",							// NAME2
 "",								// NAME3
 &PrgInit.bool_notify_send,					// FOUND
-"",								// DEPOTDEBIAN_64
-"",								// DEPOTDEBIAN_32
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
 NULL},								// DESCRIPTION
@@ -384,8 +299,6 @@ NULL},								// DESCRIPTION
 "",								// NAME2
 "",								// NAME3
 &PrgInit.bool_ps2pdf,						// FOUND
-"",								// DEPOTDEBIAN_64
-"",								// DEPOTDEBIAN_32
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
 NULL},								// DESCRIPTION
@@ -396,8 +309,6 @@ NULL},								// DESCRIPTION
 "",								// NAME2
 "",								// NAME3
 &PrgInit.bool_shorten,						// FOUND
-"shorten_3.6.1-1_amd64.deb",					// DEPOTDEBIAN_64
-"shorten_3.6.0-1_i386.deb",					// DEPOTDEBIAN_32
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
 NULL},								// DESCRIPTION
@@ -408,8 +319,6 @@ NULL},								// DESCRIPTION
 "",								// NAME2
 "",								// NAME3
 &PrgInit.bool_shntool,						// FOUND
-"",								// DEPOTDEBIAN_64
-"",								// DEPOTDEBIAN_32
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
 NULL},								// DESCRIPTION
@@ -420,8 +329,6 @@ NULL},								// DESCRIPTION
 "",								// NAME2
 "",								// NAME3
 &PrgInit.bool_sox,						// FOUND
-"",								// DEPOTDEBIAN_64
-"",								// DEPOTDEBIAN_32
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
 NULL},								// DESCRIPTION
@@ -432,8 +339,6 @@ NULL},								// DESCRIPTION
 "",								// NAME2
 "",								// NAME3
 &PrgInit.bool_oggenc,						// FOUND
-"",								// DEPOTDEBIAN_64
-"",								// DEPOTDEBIAN_32
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
 NULL},								// DESCRIPTION
@@ -444,8 +349,6 @@ NULL},								// DESCRIPTION
 "",								// NAME2
 "",								// NAME3
 &PrgInit.bool_vorbisgain,					// FOUND
-"",								// DEPOTDEBIAN_64
-"",								// DEPOTDEBIAN_32
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
 NULL},								// DESCRIPTION
@@ -456,8 +359,6 @@ NULL},								// DESCRIPTION
 "",								// NAME2
 "",								// NAME3
 &PrgInit.bool_wavsplit,						// FOUND
-"wavsplit_1.1.0-3_amd64.deb",					// DEPOTDEBIAN_64
-"wavsplit_1.1.0-3_i386.deb",					// DEPOTDEBIAN_32
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
 NULL},								// DESCRIPTION
@@ -468,8 +369,6 @@ NULL},								// DESCRIPTION
 "",								// NAME2
 "",								// NAME3
 &PrgInit.bool_wavpack,						// FOUND
-"",								// DEPOTDEBIAN_64
-"",								// DEPOTDEBIAN_32
 NULL,								// NAME TREE-VIEW
 NULL,								// PIXBUF TREE-VIEW
 NULL}								// DESCRIPTION
@@ -542,6 +441,14 @@ GdkPixbuf *prginit_get_pixbuf (TYPE_PROGINIT TypeEnum)
 {
 	return ((GdkPixbuf *)TableauPrgExtern [ TypeEnum ] . Pixbuf);
 }
+
+// 
+// 
+gchar *prginit_get_Paquage (TYPE_PROGINIT TypeEnum)
+{
+	return ((gchar *)TableauPrgExtern [ TypeEnum ] . Paquage);
+}
+
 // 
 // 
 gchar *prginit_get_Description (TYPE_PROGINIT TypeEnum)
@@ -559,6 +466,7 @@ gboolean prginit_elem_is_present (TYPE_PROGINIT TypeEnum)
 void prginit_affiche_glist (void)
 {
 	gchar		*Name;
+	gchar		*Paquage;
 	GtkAdjustment	*Adj = NULL;
 	gdouble		 AdjValue;
 	GtkTreeIter	 iter;
@@ -579,19 +487,25 @@ void prginit_affiche_glist (void)
 	
 		gtk_list_store_append (var_prgextern.Adr_List_Store, &iter);
 		
-		if (prginit_elem_is_present (index) == TRUE)
-			Name = g_strdup_printf ("<span color=\"black\"><b>%s</b></span>", prginit_get_name (index));
-		else	Name = g_strdup_printf ("<span color=\"red\"><b>%s</b></span>", prginit_get_name (index));
+		if (prginit_elem_is_present (index) == TRUE) {
+			Name    = g_strdup_printf ("<span color=\"black\"><b>%s</b></span>", prginit_get_name (index));
+			Paquage = g_strdup_printf ("<span color=\"black\"><b><i>%s</i></b></span>", prginit_get_Paquage (index));
+		}
+		else {
+			Name    = g_strdup_printf ("<span color=\"red\"><b>%s</b></span>", prginit_get_name (index));
+			Paquage = g_strdup_printf ("<span color=\"red\"><b><i>%s</i></b></span>", prginit_get_Paquage (index));
+		}
 		
 		gtk_list_store_set (var_prgextern.Adr_List_Store, &iter,
 					PRGEXT_NAME,		Name,
 					PRGEXT_STATUS,		prginit_get_pixbuf (index),
+					PRGEXT_PAQUAGE,		Paquage,
 					PRGEXT_COMMENT,		prginit_get_Description (index),
 					PRGEXT_NUM_COLUMN,	index,	
 					-1);
 
-		g_free (Name);
-		Name = NULL;
+		g_free (Name);		Name = NULL;
+		g_free (Paquage);	Paquage = NULL;
 	}
 }
 // 
@@ -766,7 +680,22 @@ static void prginit_add_columns (GtkTreeView *treeview)
 	gtk_tree_view_column_set_fixed_width (GTK_TREE_VIEW_COLUMN (column), 50);
 	gtk_tree_view_column_set_alignment (GTK_TREE_VIEW_COLUMN (column), 0.5);
 	gtk_tree_view_append_column (treeview, column);
-
+	
+	// PRGEXT_PAQUAGE
+	renderer = gtk_cell_renderer_text_new ();
+	g_object_set (renderer, "xalign", 0.0, NULL);
+	column = gtk_tree_view_column_new_with_attributes (
+							_("Paquet"),
+							renderer,
+							"markup", PRGEXT_PAQUAGE,
+							NULL);
+	gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN (column),
+				   GTK_TREE_VIEW_COLUMN_FIXED);
+	gtk_tree_view_column_set_fixed_width (GTK_TREE_VIEW_COLUMN (column), 140);
+	gtk_tree_view_column_set_alignment (GTK_TREE_VIEW_COLUMN (column), 0.5);
+	gtk_tree_view_append_column (treeview, column);
+	
+	
 	// PRGEXT_COMMENT
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set (renderer, "xalign", 0.0, NULL);
@@ -792,41 +721,75 @@ void prginit_remove_comment (void)
 			g_free (TableauPrgExtern[ index ].Description);
 			TableauPrgExtern[ index ].Description = NULL;
 		}
+		if (NULL != TableauPrgExtern[ index ].Paquage) {
+			g_free (TableauPrgExtern[ index ].Paquage);
+			TableauPrgExtern[ index ].Paquage = NULL;
+		}
 	}
 }
 // 
 // 
 void prginit_init_comment (void)
 {
-	TableauPrgExtern[ NMR_a52dec ].Description 			= g_strdup (_(" [ liba52-0.7.4-dev ] decode ATSC A/52 audio streams"));
-	TableauPrgExtern[ NMR_aacplusenc ].Description 			= g_strdup (_(" [ aacplusenc ] AAC+ encoder"));
-	TableauPrgExtern[ NMR_cdparanoia ].Description 			= g_strdup (_(" [ cdparanoia ] Extracteur cd audio"));
-	TableauPrgExtern[ NMR_checkmp3 ].Description 			= g_strdup (_(" [ checkmp3 ] Cherche des renseignements sur les formats mp3"));
-	TableauPrgExtern[ NMR_imagemagick_convert ].Description 	= g_strdup (_(" [ imagemagick ] Manipulation de formats d'images"));
-	TableauPrgExtern[ NMR_cuetools ].Description 			= g_strdup (_(" [ cuetools ] Decoupage de fichiers sans decodage"));
-	TableauPrgExtern[ NMR_faac ].Description 			= g_strdup (_(" [ faac ] Audio Codeur freeware"));
-	TableauPrgExtern[ NMR_faad ].Description 			= g_strdup (_(" [ faad ] MPEG-4 AAC decodeur"));
-	TableauPrgExtern[ NMR_flac ].Description 			= g_strdup (_(" [ flac ] Conversion wav : flac / <b><i>METAFLAC DOIT ETRE SUPERIEUR A LA VERSION: 1.1.2</i></b>"));
-	TableauPrgExtern[ NMR_icedax ].Description 			= g_strdup (_(" [ icedax ] Extracteur cd audio"));
-	TableauPrgExtern[ NMR_lame ].Description 			= g_strdup (_(" [ lame ] Conversion wav : mp3"));
-	TableauPrgExtern[ NMR_lsdvd ].Description 			= g_strdup (_(" [ lsdvd ] Cherche les informations d'un dvd"));
-	TableauPrgExtern[ NMR_mac ].Description 			= g_strdup (_(" [ monkeys-audio ] Monkey's Audio Console Front End : APE"));
-	TableauPrgExtern[ NMR_musepack_tools_mppdec ].Description 	= g_strdup (_(" [ musepack-tools ] MusePack commandline utilities : mppdec"));
-	TableauPrgExtern[ NMR_musepack_tools_mppenc ].Description 	= g_strdup (_(" [ musepack-tools ] MusePack commandline utilities : mppenc"));
-	TableauPrgExtern[ NMR_mplayer ].Description 			= g_strdup (_(" [ mplayer ] Lecteur et extracteur"));
-	TableauPrgExtern[ NMR_mp3gain ].Description 			= g_strdup (_(" [ mp3gain ] Normaliseur de fichier mp3"));
-	TableauPrgExtern[ NMR_mpg321 ].Description 			= g_strdup (_(" [ mpg321 ] Conversion mp3 : wav"));
-	TableauPrgExtern[ NMR_mp3splt ].Description 			= g_strdup (_(" [ mp3splt ] Decoupage de fichiers sans decodage"));
-	TableauPrgExtern[ NMR_normalize ].Description 			= g_strdup (_(" [ normalize-audio ] Normaliseur de fichier wav"));
-	TableauPrgExtern[ NMR_libnotify_bin ].Description 		= g_strdup (_(" [ libnotify-bin ] A program to send desktop notifications"));
-	TableauPrgExtern[ NMR_ps2pdf ].Description 			= g_strdup (_(" [ ghostscript ] Conversion  fichier  *.PS vers  *.PDF"));
-	TableauPrgExtern[ NMR_shorten ].Description 			= g_strdup (_(" [ shorten ] Forte compression au format wave"));
-	TableauPrgExtern[ NMR_shntool ].Description			= g_strdup (_(" [ shntool ] Decoupage de fichiers sans decodage"));
-	TableauPrgExtern[ NMR_sox ].Description 			= g_strdup (_(" [ sox ] Transformation universelle de fichiers son"));
-	TableauPrgExtern[ NMR_vorbis_tools_oggenc ].Description		= g_strdup (_(" [ Vorbis-tools ] Conversion wav : ogg"));
-	TableauPrgExtern[ NMR_vorbisgain ].Description 			= g_strdup (_(" [ vorbisgain ] Normaliseur de fichier ogg"));
-	TableauPrgExtern[ NMR_wavsplit ].Description 			= g_strdup (_(" [ wavsplit ] Decoupage de fichiers sans decodage"));
-	TableauPrgExtern[ NMR_wavpack ].Description 			= g_strdup (_(" [ wavpack ] WAVPACK  Hybrid Lossless Audio Compressor"));
+	TableauPrgExtern[ NMR_a52dec ].Description 			= g_strdup (_(" Decode ATSC A/52 audio streams"));
+	TableauPrgExtern[ NMR_aacplusenc ].Description 			= g_strdup (_(" AAC+ encoder"));
+	TableauPrgExtern[ NMR_cdparanoia ].Description 			= g_strdup (_(" Extracteur cd audio"));
+	TableauPrgExtern[ NMR_checkmp3 ].Description 			= g_strdup (_(" Cherche des renseignements sur les formats mp3"));
+	TableauPrgExtern[ NMR_imagemagick_convert ].Description 	= g_strdup (_(" Manipulation de formats d'images"));
+	TableauPrgExtern[ NMR_cuetools ].Description 			= g_strdup (_(" Decoupage de fichiers sans decodage"));
+	TableauPrgExtern[ NMR_faac ].Description 			= g_strdup (_(" Audio Codeur freeware"));
+	TableauPrgExtern[ NMR_faad ].Description 			= g_strdup (_(" MPEG-4 AAC decodeur"));
+	TableauPrgExtern[ NMR_flac ].Description 			= g_strdup (_(" Conversion wav : flac / <b><i>METAFLAC > 1.1.2</i></b>"));
+	TableauPrgExtern[ NMR_icedax ].Description 			= g_strdup (_(" Extracteur cd audio"));
+	TableauPrgExtern[ NMR_lame ].Description 			= g_strdup (_(" Conversion wav : mp3"));
+	TableauPrgExtern[ NMR_lsdvd ].Description 			= g_strdup (_(" Cherche les informations d'un dvd"));
+	TableauPrgExtern[ NMR_mac ].Description 			= g_strdup (_(" Monkey's Audio Console Front End : APE"));
+	TableauPrgExtern[ NMR_musepack_tools_mppdec ].Description 	= g_strdup (_(" MusePack commandline utilities : mppdec"));
+	TableauPrgExtern[ NMR_musepack_tools_mppenc ].Description 	= g_strdup (_(" MusePack commandline utilities : mppenc"));
+	TableauPrgExtern[ NMR_mplayer ].Description 			= g_strdup (_(" Lecteur et extracteur"));
+	TableauPrgExtern[ NMR_mp3gain ].Description 			= g_strdup (_(" Normaliseur de fichier mp3"));
+	TableauPrgExtern[ NMR_mpg321 ].Description 			= g_strdup (_(" Conversion mp3 : wav"));
+	TableauPrgExtern[ NMR_mp3splt ].Description 			= g_strdup (_(" Decoupage de fichiers sans decodage"));
+	TableauPrgExtern[ NMR_normalize ].Description 			= g_strdup (_(" Normaliseur de fichier wav"));
+	TableauPrgExtern[ NMR_libnotify_bin ].Description 		= g_strdup (_(" A program to send desktop notifications"));
+	TableauPrgExtern[ NMR_ps2pdf ].Description 			= g_strdup (_(" Conversion  fichier  *.PS vers  *.PDF"));
+	TableauPrgExtern[ NMR_shorten ].Description 			= g_strdup (_(" Forte compression au format wave"));
+	TableauPrgExtern[ NMR_shntool ].Description			= g_strdup (_(" Decoupage de fichiers sans decodage"));
+	TableauPrgExtern[ NMR_sox ].Description 			= g_strdup (_(" Transformation universelle de fichiers son"));
+	TableauPrgExtern[ NMR_vorbis_tools_oggenc ].Description		= g_strdup (_(" Conversion wav : ogg"));
+	TableauPrgExtern[ NMR_vorbisgain ].Description 			= g_strdup (_(" Normaliseur de fichier ogg"));
+	TableauPrgExtern[ NMR_wavsplit ].Description 			= g_strdup (_(" Decoupage de fichiers sans decodage"));
+	TableauPrgExtern[ NMR_wavpack ].Description 			= g_strdup (_(" WAVPACK  Hybrid Lossless Audio Compressor"));
+
+	TableauPrgExtern[ NMR_a52dec ].Paquage 				= g_strdup (" liba52-0.7.4-dev");
+	TableauPrgExtern[ NMR_aacplusenc ].Paquage 			= g_strdup (" aacplusenc");
+	TableauPrgExtern[ NMR_cdparanoia ].Paquage 			= g_strdup (" cdparanoia");
+	TableauPrgExtern[ NMR_checkmp3 ].Paquage 			= g_strdup (" checkmp3");
+	TableauPrgExtern[ NMR_imagemagick_convert ].Paquage 		= g_strdup (" imagemagick");
+	TableauPrgExtern[ NMR_cuetools ].Paquage 			= g_strdup (" cuetools");
+	TableauPrgExtern[ NMR_faac ].Paquage 				= g_strdup (" faac");
+	TableauPrgExtern[ NMR_faad ].Paquage 				= g_strdup (" faad");
+	TableauPrgExtern[ NMR_flac ].Paquage 				= g_strdup (" flac");
+	TableauPrgExtern[ NMR_icedax ].Paquage 				= g_strdup (" icedax");
+	TableauPrgExtern[ NMR_lame ].Paquage 				= g_strdup (" lame");
+	TableauPrgExtern[ NMR_lsdvd ].Paquage 				= g_strdup (" lsdvd");
+	TableauPrgExtern[ NMR_mac ].Paquage 				= g_strdup (" monkeys-audio");
+	TableauPrgExtern[ NMR_musepack_tools_mppdec ].Paquage 		= g_strdup (" musepack-tools");
+	TableauPrgExtern[ NMR_musepack_tools_mppenc ].Paquage 		= g_strdup (" musepack-tools");
+	TableauPrgExtern[ NMR_mplayer ].Paquage 			= g_strdup (" mplayer");
+	TableauPrgExtern[ NMR_mp3gain ].Paquage 			= g_strdup (" mp3gain");
+	TableauPrgExtern[ NMR_mpg321 ].Paquage 				= g_strdup (" mpg321");
+	TableauPrgExtern[ NMR_mp3splt ].Paquage 			= g_strdup (" mp3splt");
+	TableauPrgExtern[ NMR_normalize ].Paquage 			= g_strdup (" normalize-audio");
+	TableauPrgExtern[ NMR_libnotify_bin ].Paquage 			= g_strdup (" libnotify-bin");
+	TableauPrgExtern[ NMR_ps2pdf ].Paquage 				= g_strdup (" ghostscript");
+	TableauPrgExtern[ NMR_shorten ].Paquage 			= g_strdup (" shorten");
+	TableauPrgExtern[ NMR_shntool ].Paquage				= g_strdup (" shntool");
+	TableauPrgExtern[ NMR_sox ].Paquage 				= g_strdup (" sox");
+	TableauPrgExtern[ NMR_vorbis_tools_oggenc ].Paquage		= g_strdup (" Vorbis-tools");
+	TableauPrgExtern[ NMR_vorbisgain ].Paquage 			= g_strdup (" vorbisgain");
+	TableauPrgExtern[ NMR_wavsplit ].Paquage 			= g_strdup (" wavsplit");
+	TableauPrgExtern[ NMR_wavpack ].Paquage 			= g_strdup (" wavpack");
 }
 // INITIALISATION DU SCROLLWINDOW
 // 
@@ -844,6 +807,7 @@ void on_scrolledwindow_applications_externes_realize (GtkWidget *widget, gpointe
 	store = gtk_list_store_new (PRGEXT_TOTAL_COLUMN,	// Nombre total de colonnes
 				    G_TYPE_STRING,		// Name
 				    GDK_TYPE_PIXBUF,		// Status
+				    G_TYPE_STRING,		// Paquage
 				    G_TYPE_STRING,		// Commentaire
 				    G_TYPE_INT
 				    );
