@@ -1,50 +1,43 @@
  /*
- * file      : prg_init.h
- * project   : xcfa
- * with      : Gtk-2
+ *  file      : prg_init.h
+ *  project   : xcfa
+ *  with      : Gtk-2
  *
- * copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2011 by Claude Bulin
  *
- * xcfa - GTK+ implementation of the GNU shell command
- * GNU General Public License
+ *  xcfa - GTK+ implementation of the GNU shell command
+ *  GNU General Public License
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * OLD ADRESS:
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- * NEW ADRESS:
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *  This file is part of XCFA.
  * 
+ *  XCFA is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  at your option) any later version.
+ * 
+ *  XCFA is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ * 
+ *  You should have received a copy of the GNU General Public License
+ *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
+
 #ifndef prg_init_h
 #define prg_init_h 1
 
+
 typedef struct {
 	GtkListStore      *Adr_List_Store;
 	GtkTreeModel      *Adr_Tree_Model;
 	GtkWidget         *Adr_scroll;
 	GtkTreeSelection  *Adr_Line_Selected;
 	gboolean           Bool_Goto_Page_Options;
-	// GdkPixbuf         *Pixbuf_Coche;
-	// GdkPixbuf         *Pixbuf_Selected;
 	GdkPixbuf         *Pixbuf_Ok;
 	GdkPixbuf         *Pixbuf_Not_Ok;
-
 } VAR_PRGEXTERN;
 
 extern VAR_PRGEXTERN var_prgextern;
@@ -64,14 +57,9 @@ typedef enum {
 	NMR_icedax,
 	NMR_lame,
 	NMR_lsdvd,
-	
 	NMR_mac,
-	
-	// NMR_mpc123_mppdec,
-	// NMR_mppenc,
 	NMR_musepack_tools_mppdec,
 	NMR_musepack_tools_mppenc,
-	
 	NMR_mplayer,
 	NMR_mp3gain,
 	NMR_mpg321,
@@ -99,10 +87,9 @@ typedef struct {
 	gchar		*Name2;					// NAME2
 	gchar		*Name3;					// NAME3
 	gboolean	*BoolFound;				// FOUND
-	gchar		*DepotDebian64;				// DEPOTDEBIAN_64
-	gchar		*DepotDebian32;				// DEPOTDEBIAN_32
 	gchar		*PtrName;				// NAME TREE-VIEW : pointeur sur Name1 | Name2 | Name3
 	GdkPixbuf	*Pixbuf;				// PIXBUF TREE-VIEW
+	gchar		*Paquage;				// PAQUAGE
 	gchar		*Description;				// DESCRIPTION TREE-VIEW
 } TABLEAU_PRG_EXTERN;
 
@@ -148,7 +135,6 @@ extern PRGINIT PrgInit;
 
 
 void       prginit_remove_comment (void);
-// void       prginit_make_scrolledwindow (GtkWidget *widget);
 gboolean   prginit_get_etat (void);
 void       prginit_update_glist (void);
 gchar     *prginit_get_name (TYPE_PROGINIT TypeEnum);
