@@ -1,33 +1,27 @@
  /*
- * file      : scan_cd.c
- * project   : xcfa
- * with      : Gtk-2
+ *  file      : scan_cd.c
+ *  project   : xcfa
+ *  with      : Gtk-2
  *
- * copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2011 by Claude Bulin
  *
- * xcfa - GTK+ implementation of the GNU shell command
- * GNU General Public License
+ *  xcfa - GTK+ implementation of the GNU shell command
+ *  GNU General Public License
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * OLD ADRESS:
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- * NEW ADRESS:
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *  This file is part of XCFA.
  * 
+ *  XCFA is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  at your option) any later version.
+ * 
+ *  XCFA is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ * 
+ *  You should have received a copy of the GNU General Public License
+ *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -236,7 +230,8 @@ void scan_remove_glist_media (void)
 	g_print ("\tRemove: %d\n", NbList);
 }
 
-
+// 
+// 
 GList *scan_scan_drives_cd_dvd (void)
 {
 	GString      *gstr = NULL;	
@@ -396,11 +391,11 @@ GList *scan_scan_drives_cd_dvd (void)
 	return (List);
 }
 
-/* Retourne un pointeur sur le media actif
-*/
+// Retourne un pointeur sur le media actif
+// 
 gchar *scan_get_text_combo_cd (TYPE_READER type_reader)
 {
-	gint   Nmr_Combo_Actif = 0;
+	gint   Nmr_Combo_Actif = -1;
 	GList *List = NULL;
 	MEDIA *Media = NULL;
 
@@ -411,10 +406,12 @@ gchar *scan_get_text_combo_cd (TYPE_READER type_reader)
 	}
 	else if (type_reader == _DVD_) {
 		Nmr_Combo_Actif = gtk_combo_box_get_active (var_dvd.Adr_ComboBox_Reader);
+		
+		if( dvd_bool_read_dvd_from_directory () == TRUE ) {
+			return( (gchar *)var_dvd.from.path );
+		}
 	}
-	else if (dvd_bool_read_dvd_from_directory () == TRUE) {
-		return ((gchar *)var_dvd.from.path);
-	}
+	
 	List = g_list_first (var_scancd.Media_List);
 	while (List) {
 		if ((Media = (MEDIA *)List->data)) {
@@ -426,6 +423,8 @@ gchar *scan_get_text_combo_cd (TYPE_READER type_reader)
 	return ((gchar *)NULL);
 }
 
+// 
+// 
 GList *scan_get_glist (void)
 {
 	if (var_scancd.Media_List == NULL)
@@ -434,11 +433,10 @@ GList *scan_get_glist (void)
 	return ( (GList *)var_scancd.Media_List);
 }
 
+// 
+// 
 void scan_eject_media (TYPE_READER TypeReadder)
 {
-	/*
-	EnteteCD.NameCD_Device = scan_get_text_combo_cd (_DVD_);
-	*/
 	GetInfo_eject ( scan_get_text_combo_cd (TypeReadder));
 
 }
