@@ -1,33 +1,27 @@
  /*
- * file      : split_conv.c
- * project   : xcfa
- * with      : Gtk-2
+ *  file      : split_conv.c
+ *  project   : xcfa
+ *  with      : Gtk-2
  *
- * copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2011 by Claude Bulin
  *
- * xcfa - GTK+ implementation of the GNU shell command
- * GNU General Public License
+ *  xcfa - GTK+ implementation of the GNU shell command
+ *  GNU General Public License
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * OLD ADRESS:
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- * NEW ADRESS:
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *  This file is part of XCFA.
  * 
+ *  XCFA is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  at your option) any later version.
+ * 
+ *  XCFA is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ * 
+ *  You should have received a copy of the GNU General Public License
+ *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -152,10 +146,6 @@ static void SplitConv_thread (void *arg)
 		conv.ArgConv [ pos++ ] = NULL;
 		conv_to_convert (FALSE, MPLAYER_WAV_TO_WAV, "MPLAYER_WAV_TO_WAV");
 		filelc_get_command_line_remove ();
-		
-		// conv_with_sox_get_param (SPLIT_FILE_TMP_WAV_SOX, SPLIT_FILE_TMP_WAV, "44100", "2", "16");
-		// conv_to_convert (FALSE, SOX_WAV_TO_WAV, "SOX_WAV_TO_WAV");
-		// filelc_get_command_line_remove ();
 		BoolPassSox = TRUE;
 	}
 	else if (FILE_IS_FLAC == VarSplitConv.TypeFileIs) {
@@ -171,10 +161,6 @@ static void SplitConv_thread (void *arg)
 		filelc_get_command_line (&param_filelc);
 		conv_to_convert (FALSE, FLAC_FLAC_TO_WAV, "FLAC_FLAC_TO_WAV");
 		filelc_get_command_line_remove ();
-		
-		// conv_with_sox_get_param (SPLIT_FILE_TMP_WAV_SOX, SPLIT_FILE_TMP_WAV, "44100", "2", "16");
-		// conv_to_convert (FALSE, SOX_WAV_TO_WAV, "SOX_WAV_TO_WAV");
-		// filelc_get_command_line_remove ();
 		BoolPassSox = TRUE;
 	}
 	else if (FILE_IS_APE == VarSplitConv.TypeFileIs) {
@@ -187,14 +173,9 @@ static void SplitConv_thread (void *arg)
 		param_filelc.num_track            = NULL;
 		param_filelc.BoolSetBitrate       = FALSE;
 		param_filelc.PtrStrBitrate        = NULL;
-		
 		filelc_get_command_line (&param_filelc);
 		conv_to_convert (FALSE, MAC_APE_TO_WAV, "MAC_APE_TO_WAV");
 		filelc_get_command_line_remove ();
-		
-		// conv_with_sox_get_param (SPLIT_FILE_TMP_WAV_SOX, SPLIT_FILE_TMP_WAV, "44100", "2", "16");
-		// conv_to_convert (FALSE, SOX_WAV_TO_WAV, "SOX_WAV_TO_WAV");
-		// filelc_get_command_line_remove ();
 		BoolPassSox = TRUE;
 	}
 	else if (FILE_IS_WAVPACK == VarSplitConv.TypeFileIs) {
@@ -212,10 +193,6 @@ static void SplitConv_thread (void *arg)
 		conv.ArgConv [ pos++ ] = NULL;
 		conv_to_convert (FALSE, MPLAYER_OGG_TO_WAV, "MPLAYER_OGG_TO_WAV");
 		filelc_get_command_line_remove ();
-		
-		// conv_with_sox_get_param (SPLIT_FILE_TMP_WAV_SOX, SPLIT_FILE_TMP_WAV, "44100", "2", "16");
-		// conv_to_convert (FALSE, SOX_WAV_TO_WAV, "SOX_WAV_TO_WAV");
-		// filelc_get_command_line_remove ();
 		BoolPassSox = TRUE;
 	}
 	else if (FILE_IS_M4A == VarSplitConv.TypeFileIs) {
@@ -235,13 +212,26 @@ static void SplitConv_thread (void *arg)
 		conv.ArgConv [ pos++ ] = NULL;
 		conv_to_convert (FALSE, MPLAYER_MP3_TO_WAV, "MPLAYER_MP3_TO_WAV");
 		filelc_get_command_line_remove ();
-		
-		// conv_with_sox_get_param (SPLIT_FILE_TMP_WAV_SOX, SPLIT_FILE_TMP_WAV, "44100", "2", "16");
-		// conv_to_convert (FALSE, SOX_WAV_TO_WAV, "SOX_WAV_TO_WAV");
-		// filelc_get_command_line_remove ();
 		BoolPassSox = TRUE;
 	}
 	else if (FILE_IS_WMA == VarSplitConv.TypeFileIs) {
+		pos = filelc_get_command_line_nice ();
+		conv.ArgConv [ pos++ ] = g_strdup ("mplayer");
+		conv.ArgConv [ pos++ ] = g_strdup ("-nojoystick");
+		conv.ArgConv [ pos++ ] = g_strdup ("-nolirc");
+		conv.ArgConv [ pos++ ] = g_strdup (VarSplitConv.SrcPathnameFile);
+		conv.ArgConv [ pos++ ] = g_strdup ("-ao");
+		conv.ArgConv [ pos++ ] = g_strdup ("pcm");
+		conv.ArgConv [ pos++ ] = g_strdup ("-ao");
+		conv.ArgConv [ pos++ ] = g_strdup_printf ("pcm:file=%s", SPLIT_FILE_TMP_WAV_SOX);
+		conv.ArgConv [ pos++ ] = g_strdup ("-af");
+		conv.ArgConv [ pos++ ] = g_strdup ("channels=2");
+		conv.ArgConv [ pos++ ] = g_strdup ("-srate");
+		conv.ArgConv [ pos++ ] = g_strdup ("44100");
+		conv.ArgConv [ pos++ ] = NULL;
+		conv_to_convert (FALSE, MPLAYER_WMA_TO_WAV, "MPLAYER_WMA_TO_WAV");
+		filelc_get_command_line_remove ();
+		BoolPassSox = TRUE;
 	}
 	else if (FILE_IS_SHN == VarSplitConv.TypeFileIs) {
 	}
@@ -289,7 +279,6 @@ static gint SplitConv_timeout (gpointer data)
 		}
 		
 		WindScan_set_label (Str);
-		// while (gtk_events_pending()) gtk_main_iteration();
 	}
 	if (FILE_IS_NONE != VarSplitConv.TypeFileIs && TRUE == conv.bool_percent_conv) {
 		
@@ -300,7 +289,6 @@ static gint SplitConv_timeout (gpointer data)
 		g_free (Str);
 		Str = NULL;
 		conv.bool_percent_conv = FALSE;
-		// while (gtk_events_pending()) gtk_main_iteration();
 	}
 	else if (TRUE == conv.bool_thread_conv) {
 	}
@@ -396,6 +384,10 @@ void SplitConv_to (gchar *p_PathNameFile)
 		VarSplitConv.DestPathnameFile = g_strdup (SPLIT_FILE_TMP_WAV);
 		conv.total_convert = 2;
 	}
+	else if (FILE_IS_WMA == VarSplitConv.TypeFileIs) {
+		VarSplitConv.DestPathnameFile = g_strdup (SPLIT_FILE_TMP_WAV);
+		conv.total_convert = 2;
+	}
 	if (FILE_IS_NONE != VarSplitConv.TypeFileIs) {
 		WindScan_open ("SOX files", WINDSCAN_PULSE);
 		WindScan_set_label ("<b><i>SOX files ...</i></b>");
