@@ -1,33 +1,27 @@
  /*
- * file      : split_cue.c
- * project   : xcfa
- * with      : Gtk-2
+ *  file      : split_cue.c
+ *  project   : xcfa
+ *  with      : Gtk-2
  *
- * copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2011 by Claude Bulin
  *
- * xcfa - GTK+ implementation of the GNU shell command
- * GNU General Public License
+ *  xcfa - GTK+ implementation of the GNU shell command
+ *  GNU General Public License
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * OLD ADRESS:
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- * NEW ADRESS:
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *  This file is part of XCFA.
  * 
+ *  XCFA is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  at your option) any later version.
+ * 
+ *  XCFA is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ * 
+ *  You should have received a copy of the GNU General Public License
+ *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -236,16 +230,16 @@ gchar *SplitCue_read_cue_file (gchar *p_pathname)
 		else if (strstr (buf, "INDEX 01")) {
 			IndicePoints ++;
 			VarSplit.Selecteur [ IndicePoints ] . Nmr             = IndicePoints;
-			VarSplit.Selecteur [ IndicePoints ] . Begin           = SplitCue_get_time_in_sec (buf);
-			VarSplit.Selecteur [ IndicePoints ] . PercentBegin    = ((gdouble)VarSplit.Selecteur [ IndicePoints ] . Begin / (gdouble)FileTimeSec) * 100.0;
+			VarSplit.Selecteur [ IndicePoints ] . BeginPaint      = SplitCue_get_time_in_sec (buf);
+			VarSplit.Selecteur [ IndicePoints ] . PercentBegin    = ((gdouble)VarSplit.Selecteur [ IndicePoints ] . BeginPaint / (gdouble)FileTimeSec) * 100.0;
 		} 
 		
 		// FIN
 		
 		else if (strstr (buf, "INDEX 00")) {
 			VarSplit.Selecteur [ IndicePoints ] . Nmr             = IndicePoints;
-			VarSplit.Selecteur [ IndicePoints ] . End             = SplitCue_get_time_in_sec (buf);
-			VarSplit.Selecteur [ IndicePoints ] . PercentEnd      = ((gdouble)VarSplit.Selecteur [ IndicePoints ] . End / (gdouble)FileTimeSec) * 100.0;
+			VarSplit.Selecteur [ IndicePoints ] . EndPaint        = SplitCue_get_time_in_sec (buf);
+			VarSplit.Selecteur [ IndicePoints ] . PercentEnd      = ((gdouble)VarSplit.Selecteur [ IndicePoints ] . EndPaint / (gdouble)FileTimeSec) * 100.0;
 		}
 		
 		else if (strstr (buf, "TITLE ")) {
@@ -256,11 +250,11 @@ gchar *SplitCue_read_cue_file (gchar *p_pathname)
 	fclose (fp);
 	
 	// AJUSTER LE DEBUT
-	VarSplit.Selecteur [ 0 ] . Begin         = 1;
+	VarSplit.Selecteur [ 0 ] . BeginPaint         = 1;
 	
 	// AJUSTER LA FIN
 	VarSplit.Selecteur [ IndicePoints ] . PercentEnd    = 99.99;
-	VarSplit.Selecteur [ IndicePoints ] . End           = FileTimeSec;
+	VarSplit.Selecteur [ IndicePoints ] . EndPaint      = FileTimeSec;
 	
 	// TESTER LA COHERENCE DES DATAS
 	BoolResultOk = TRUE;
@@ -269,17 +263,17 @@ gchar *SplitCue_read_cue_file (gchar *p_pathname)
 		g_print ("[ %2d ]   TIME = %05d  BEGIN = %5d  END = %5d  PERCENTBEGIN = %f  PERCENTEND = %f\n",
 			VarSplit.Selecteur [ IndicePoints ] . Nmr,
 			FileTimeSec,
-			(gint)VarSplit.Selecteur [ IndicePoints ] . Begin,
-			(gint)VarSplit.Selecteur [ IndicePoints ] . End,
+			(gint)VarSplit.Selecteur [ IndicePoints ] . BeginPaint,
+			(gint)VarSplit.Selecteur [ IndicePoints ] . EndPaint,
 			VarSplit.Selecteur [ IndicePoints ] . PercentBegin,
 			VarSplit.Selecteur [ IndicePoints ] . PercentEnd
 			);
-		if ((gint)VarSplit.Selecteur [ IndicePoints ] . Begin > (gint)VarSplit.Selecteur [ IndicePoints ] . End) {
+		if ((gint)VarSplit.Selecteur [ IndicePoints ] . BeginPaint > (gint)VarSplit.Selecteur [ IndicePoints ] . EndPaint) {
 			BoolResultOk = FALSE;
 			g_print ("\t--- ERREUR [ 1 ] DE DATAS DANS LE FICHIER CUE !!! ---\n");
 		}
 		if (VarSplit.Selecteur [ IndicePoints +1 ] . Nmr != -1) {
-			if ((gint)VarSplit.Selecteur [ IndicePoints ] . End > (gint)VarSplit.Selecteur [ IndicePoints +1 ] . Begin) {
+			if ((gint)VarSplit.Selecteur [ IndicePoints ] . EndPaint > (gint)VarSplit.Selecteur [ IndicePoints +1 ] . BeginPaint) {
 				BoolResultOk = FALSE;
 				g_print ("\t--- [ 2 ] ERREUR DE DATAS DANS LE FICHIER CUE !!! ---\n");
 			}
