@@ -55,6 +55,8 @@ extern ADJUST Adjust;
 
 
 
+
+
 // 
 // 
 gint SplitSpectre_get_with (void)
@@ -769,6 +771,17 @@ gboolean SplitSpectre_read_file_spectre (gchar *PathNameFile)
 	
 	VarSplit.MaxPointsInTab = points;
 	
+	// ALL DATAS
+	// points * BLOCK_SIZE
+	g_print( "points(%d) * BLOCK_SIZE(%d) = \n\t%d octets\n\t%d Ko\n\t%d Mo\n\n",
+					points, 
+					BLOCK_SIZE, 
+					points * BLOCK_SIZE,
+					(points * BLOCK_SIZE) / 1024, 
+					((points * BLOCK_SIZE) / 1024) / 1024
+					 );
+	
+	
 	// TODO: MARQUAGE DES PASSAGES BLANC SOIT < ~-50 dB
 	for (Indice = 0; Indice < points; Indice ++) {
 		if (VarSplit.Tab [ Indice ].Min >= -1. && VarSplit.Tab [ Indice ].Max <= 1.) {
@@ -1002,73 +1015,7 @@ void SplitSpectre_draw_lines (void)
 					);
 		
 		}
-		
-		/*
-		begin    = save_begin;
-		for (points = 0; begin < end; begin ++, points ++) {
 				
-			// if( 0 == ( points & 1 )) {
-				
-				// MaxScale_0
-				if (begin >= SelBegin &&  begin <= SelEnd) {
-					// LA SELECTION
-					CRAYON_BLEU
-				} else {
-					// LA NON SELECTION
-					CRAYON_NOIR
-				}
-				gdk_draw_point (VarSplit.AdrWidgetSpectre->window,
-						gc,
-						points,
-						VarSplit.MaxScale_0 [ points ] . y
-						);
-				gdk_draw_point (VarSplit.AdrWidgetSpectre->window,
-						gc,
-						points,
-						VarSplit.MinScale_0 [ points ] . y
-						);
-			
-				// MaxScale_1
-				if (begin >= SelBegin &&  begin <= SelEnd) {
-					// LA SELECTION
-					CRAYON_BLEU_CLAIR
-				} else {
-					// LA NON SELECTION
-					CRAYON_GRIS
-				}
-				gdk_draw_point (VarSplit.AdrWidgetSpectre->window,
-						gc,
-						points,
-						VarSplit.MaxScale_1 [ points ] . y
-						);
-				gdk_draw_point (VarSplit.AdrWidgetSpectre->window,
-						gc,
-						points,
-						VarSplit.MinScale_1 [ points ] . y
-						);
-			
-				// MaxScale_2
-				if (begin >= SelBegin &&  begin <= SelEnd) {
-					// LA SELECTION
-					CRAYON_BLEU_CLAIR_PLUS
-				} else {
-					// LA NON SELECTION
-					CRAYON_GRIS_CLAIR
-				}
-				gdk_draw_point (VarSplit.AdrWidgetSpectre->window,
-						gc,
-						points,
-						VarSplit.MaxScale_2 [ points ] . y
-						);
-				gdk_draw_point (VarSplit.AdrWidgetSpectre->window,
-						gc,
-						points,
-						VarSplit.MinScale_2 [ points ] . y
-						);
-			// }
-		}
-		*/
-		
 		// AFFICHE CURSEUR DEBUT
 		if (SelBegin >= save_begin && SelBegin < Len) {
 			CRAYON_ORANGE
