@@ -1,33 +1,27 @@
  /*
- * file      : wind_about.c
- * project   : xcfa
- * with      : Gtk-2
+ *  file      : wind_about.c
+ *  project   : xcfa
+ *  with      : Gtk-2
  *
- * copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2011 by Claude Bulin
  *
- * xcfa - GTK+ implementation of the GNU shell command
- * GNU General Public License
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * OLD ADRESS:
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- * NEW ADRESS:
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *  xcfa - GTK+ implementation of the GNU shell command
+ *  GNU General Public License
  *
+ *  This file is part of XCFA.
+ * 
+ *  XCFA is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  at your option) any later version.
+ * 
+ *  XCFA is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ * 
+ *  You should have received a copy of the GNU General Public License
+ *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
 
  
@@ -50,6 +44,7 @@
 #include "global.h"
 #include "get_info.h"
 #include "web.h"
+#include "popup_systray.h"
 #include "win_about.h"
 
 
@@ -73,6 +68,7 @@ gboolean on_wind_about_delete_event (GtkWidget *widget, GdkEvent *event, gpointe
 {
 	gtk_widget_hide (VarWinAbout.AdrWin);
 	VarWinAbout.IsShow = FALSE;
+	PopupSystray_set_BoolMainAction (FALSE);
 	return (TRUE);
 }
 // 
@@ -81,6 +77,7 @@ gboolean on_wind_about_destroy_event (GtkWidget *widget, GdkEvent *event, gpoint
 {
 	gtk_widget_hide (VarWinAbout.AdrWin);
 	VarWinAbout.IsShow = FALSE;
+	PopupSystray_set_BoolMainAction (FALSE);
 	return (TRUE);
 }
 // 
@@ -89,6 +86,7 @@ void on_button_ok_about_clicked (GtkButton *button, gpointer user_data)
 {
 	VarWinAbout.IsShow = FALSE;
 	gtk_widget_hide (VarWinAbout.AdrWin);
+	PopupSystray_set_BoolMainAction (FALSE);
 }
 // 
 // 
@@ -146,29 +144,41 @@ void on_textview_label_license_about_realize (GtkWidget *widget, gpointer user_d
 	gtk_text_view_set_justification (GTK_TEXT_VIEW (widget), GTK_JUSTIFY_CENTER);
 	gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW (widget), FALSE);
 	gtk_text_buffer_set_text (gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget)),
-	"\n\nLicense 2003 - 2011, Claude Bulin\n\n\nThis program is free software;"
-	" you can redistribute it and/or modify\nit under the terms of the GNU General Public License as published by\n"
-	"the Free Software Foundation; either version 2 of the License, or\n(at your option) any later version.\n \n"
-	"This program is distributed in the hope that it will be useful,\nbut WITHOUT ANY WARRANTY; "
-	"without even the implied warranty of\nMERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  "
-	"See the\nGNU General Public License for more details.\n \nYou should have received a copy of the GNU General Public License\n"
-	/*
-	"along with this program; if not, write to the Free Software\nFoundation, Inc., 59 Temple Place - Suite 330, Boston, "
-	"MA 02111-1307, USA.\n\n------------\n\nPermission  est  donnee  a  tout  individu  ou  institution d'utiliser,\n"
+	"\n\nCopyright (C) 2003 - 2011\n\n\n"
+	"XCFA is free software; you can redistribute it and/or modify\n"
+	"it under the terms of the GNU General Public License as published by\n"
+	"the Free Software Foundation; either version 3 of the License, or\n"
+	"(at your option) any later version.\n\n"
+	"XCFA is distributed in the hope that it will be useful,\n"
+	"but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
+	"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the\n"
+	"GNU General Public License for more details.\n\n"
+	"You should have received a copy of the GNU General Public License\n"
+	"along with this program; if not, see\n"
+	"http://www.gnu.org/licenses\n"
+	"or write to\n"
+	"the Free Software Foundation,Inc.\n"
+	"51 Franklin Street\n"
+	"Fifth Floor\n"
+	"Boston, MA 02110-1301 USA\n\n------------\n\n"
 	
-	Il faut remplacer l'adresse de la FSF (qui a changé depuis juillet 2005) dans le fichier copyright.
-	Ancienne adresse: 59 Temple Place - Suite 330, Boston, MA 02111-1307 USA
-	Nouvelel adresse: 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-	*/
-	"along with this program; if not, write to the Free Software\nFoundation, Inc., 51 Franklin Street, Fifth Floor, Boston, "
-	"MA 02110-1301, USA.\n\n------------\n\nPermission  est  donnee  a  tout  individu  ou  institution d'utiliser,\n"
+	"XCFA est un logiciel libre, vous pouvez le redistribuer\n"
+	"et / ou le modifier selon les termes de la Licence Publique Générale GNU\n"
+	"telle que publiée par la Free Software Foundation; soit la version 3 de\n"
+	"la Licence, ou (à votre choix) toute version ultérieure.\n\n"
+	"XCFA est distribué dans l'espoir qu'il sera utile, mais SANS AUCUNE GARANTIE,\n"
+	"sans même la garantie implicite de COMMERCIALISATION ou D'ADAPTATION A UN\n"
+	"USAGE PARTICULIER. Voir la Licence Publique Générale GNU pour plus de détails.\n\n"
+	"Vous devriez avoir reçu une copie de la Licence Publique Générale GNU avec\n"
+	"ce programme, sinon, voir\n"
+	"http://www.gnu.org/licenses\n"
+	"ou écrivez à la\n"
+	"Free Software Foundation, Inc,\n"
+	"51 Franklin Street\n"
+	"Fifth Floor\n"
+	"Boston, Massachusetts, USA 02110-1301\n"
 	
-	"copier, ou redistribuer ce logiciel des  lors  que  tous  les  fichiers\nd'origine  sont  inclus,  que ce n'est pas vendu"
-	" pour des benefices, et\nque cette notice sur le copyright est incluse.\n\nCe programme est un logiciel libre; vous pouvez le  "
-	"redistribuer  et/ou\nle modifier sous les termes de la licence GNU GPL telle que publiee par\nla Free Software Foundation; "
-	"soit la version 2, soit  (a  votre  conve-\nnance) toute version ulterieure.\n\nCe  programme  est  distribue dans l'espoir "
-	"qu'il soit utile, mais SANS\nAUCUNE GARANTIE; meme sans la garantie implicite  de  UTILISABILITE  ou\nd'ADAPTATION  A  UN "
-	"USAGE PRECIS. Lisez la licence GNU GPL pour plus de\ndetails.\n", -1);
+	, -1);
 }
 // 
 // 
@@ -242,6 +252,17 @@ void on_label_xcfa_about_realize (GtkWidget *widget, gpointer user_data)
 }
 // 
 // 
+void on_image_gpl_xcfa_about_realize (GtkWidget *widget, gpointer user_data)
+{
+	gchar     *LineCommand = NULL;
+
+	LineCommand = libutils_get_pathname_pixmaps ("xcfa/gplv3.png");
+	gtk_image_set_from_file (GTK_IMAGE (widget), LineCommand);
+	g_free (LineCommand);
+	LineCommand = NULL;
+}
+// 
+// 
 void on_image_about_realize (GtkWidget *widget, gpointer user_data)
 {
 	gchar     *LineCommand = NULL;
@@ -271,6 +292,7 @@ void WinAbout_open (gchar *title)
 	}
 	VarWinAbout.IsShow = TRUE;
 	if (NULL != title) gtk_window_set_title (GTK_WINDOW (VarWinAbout.AdrWin), title);
-
+	
+	PopupSystray_set_BoolMainAction (TRUE);
 }
 
